@@ -1,18 +1,3 @@
-# add global variable
-if (getRversion() >= "2.15.1") {
-  utils::globalVariables(unique(c(
-    "labelp", # cor plot
-    c("x"), # facetdensitystrip plot
-    c("x"), # density diagonal plot
-    c("x", "y", "lab"), # internal axis plot
-    c("x", "y", "result", "freq"), # fluctuation plot
-    c("weight") # ggally_summarise_by
-  )))
-}
-
-
-
-
 # retrieve the evaulated data column given the aes (which could possibly do operations)
 #' Evaluate data column
 #' @param data data set to evaluate the data with
@@ -33,7 +18,7 @@ eval_data_col <- function(data, aes_col) {
 #' mapping <- ggplot2::aes(Petal.Length)
 #' mapping_string(mapping$x)
 mapping_string <- function(aes_col) {
-  gsub("^~", "", deparse(aes_col, 500L))
+  gsub("^~(?:\\.data\\$)?", "", deparse(aes_col, 500L))
 }
 
 # is categories on the left?
@@ -160,7 +145,15 @@ ggally_points <- function(data, mapping, ...) {
 #' data(tips)
 #' p_(ggally_smooth(tips, mapping = ggplot2::aes(x = total_bill, y = tip)))
 #' p_(ggally_smooth(tips, mapping = ggplot2::aes(total_bill, tip, color = sex)))
-ggally_smooth <- function(data, mapping, ..., method = "lm", formula = y ~ x, se = TRUE, shrink = TRUE) {
+ggally_smooth <- function(
+  data,
+  mapping,
+  ...,
+  method = "lm",
+  formula = y ~ x,
+  se = TRUE,
+  shrink = TRUE
+) {
   p <- ggplot(data = data, mapping)
 
   p <- p + geom_point(...)
@@ -168,7 +161,13 @@ ggally_smooth <- function(data, mapping, ..., method = "lm", formula = y ~ x, se
   if (!is.null(mapping$color) || !is.null(mapping$colour)) {
     p <- p + geom_smooth(method = method, se = se, formula = formula)
   } else {
-    p <- p + geom_smooth(method = method, se = se, formula = formula, colour = I("black"))
+    p <- p +
+      geom_smooth(
+        method = method,
+        se = se,
+        formula = formula,
+        colour = I("black")
+      )
   }
 
   if (isTRUE(shrink)) {
@@ -225,7 +224,7 @@ ggally_density <- function(data, mapping, ...) {
   p <- ggplot(data = data) +
     geom_point(
       data = data.frame(rangeX = rangeX, rangeY = rangeY),
-      mapping = aes(x = !!as.name("rangeX"), y = !!as.name("rangeY")),
+      mapping = aes(x = .data$rangeX, y = .data$rangeY),
       alpha = 0
     )
 
@@ -254,17 +253,19 @@ ggally_density <- function(data, mapping, ...) {
 #'   \item{\code{""}}{otherwise}
 #' }
 #' @param method \code{method} supplied to cor function
-#' @param use \code{use} supplied to \code{\link[stats]{cor}} function
 #' @param display_grid if \code{TRUE}, display aligned panel grid lines. If \code{FALSE} (default), display a thin panel border.
 #' @param digits number of digits to be displayed after the decimal point. See \code{\link[base]{formatC}} for how numbers are calculated.
 #' @param title_args arguments being supplied to the title's \code{\link[ggplot2]{geom_text}()}
 #' @param group_args arguments being supplied to the split-by-color group's \code{\link[ggplot2]{geom_text}()}
 #' @param justify_labels \code{justify} argument supplied when \code{\link[base]{format}}ting the labels
 #' @param align_percent relative align position of the text. When \code{justify_labels = 0.5}, this should not be needed to be set.
-#' @param alignPercent,displayGrid deprecated. Please use their snake-case counterparts.
+#' @param use `r lifecycle::badge("deprecated")`. This variable is not used internally. Please remove it from your code.
+#' @param alignPercent,displayGrid `r lifecycle::badge("deprecated")`. Please use their snake-case counterparts.
 #' @param title title text to be displayed
 #' @author Barret Schloerke
 #' @importFrom stats complete.cases cor
+#' @importFrom lifecycle deprecated
+#' @inheritParams ggally_statistic
 #' @seealso \code{\link{ggally_statistic}}, \code{\link{ggally_cor_v1_5}}
 #' @export
 #' @keywords hplot
@@ -295,37 +296,47 @@ ggally_density <- function(data, mapping, ...) {
 #'   size = 5
 #' ))
 ggally_cor <- function(
-    data,
-    mapping,
-    ...,
-    stars = TRUE,
-    method = "pearson",
-    use = "complete.obs",
-    display_grid = FALSE,
-    digits = 3,
-    title_args = list(...),
-    group_args = list(...),
-    justify_labels = "right",
-    align_percent = 0.5,
-    title = "Corr",
-    alignPercent = warning("deprecated. Use `align_percent`"),
-    displayGrid = warning("deprecated. Use `display_grid`")) {
-  if (!missing(alignPercent)) {
-    warning("`alignPercent` is deprecated. Please use `align_percent` if alignment still needs to be adjusted")
-    align_percent <- alignPercent
-  }
-  if (!missing(displayGrid)) {
-    warning("`displayGrid` is deprecated. Please use `display_grid`")
-    display_grid <- displayGrid
+  data,
+  mapping,
+  ...,
+  stars = TRUE,
+  method = "pearson",
+  display_grid = FALSE,
+  digits = 3,
+  title_args = list(...),
+  group_args = list(...),
+  justify_labels = "right",
+  align_percent = 0.5,
+  title = "Corr",
+  na.rm = NA,
+  use = deprecated(),
+  alignPercent = deprecated(),
+  displayGrid = deprecated()
+) {
+  if (lifecycle::is_present(use)) {
+    lifecycle::deprecate_warn(
+      when = "2.3.0",
+      what = "ggally_cor(use)",
+      details = "`use=` is not leveraged within `ggally_cor()`. Please remove it from your code.`"
+    )
   }
 
-  na.rm <-
-    if (missing(use)) {
-      # display warnings
-      NA
-    } else {
-      (use %in% c("complete.obs", "pairwise.complete.obs", "na.or.complete"))
-    }
+  if (lifecycle::is_present(alignPercent)) {
+    lifecycle::deprecate_soft(
+      when = "2.3.0",
+      what = "ggally_cor(alignPercent)",
+      details = "Please use `align_percent` if alignment still needs to be adjusted."
+    )
+    align_percent <- alignPercent
+  }
+  if (lifecycle::is_present(displayGrid)) {
+    lifecycle::deprecate_soft(
+      when = "2.3.0",
+      what = "ggally_cor(displayGrid)",
+      details = "Please use `display_grid`"
+    )
+    display_grid <- displayGrid
+  }
 
   ggally_statistic(
     data = data,
@@ -347,7 +358,12 @@ ggally_cor <- function(
         y <- as.numeric(y)
       }
 
-      corObj <- stats::cor.test(x, y, method = method, use = use)
+      if (length(x) < 3 | length(y) < 3) {
+        cli::cli_warn("Less than 2 observations, returning {.code NA}")
+        return("NA")
+      }
+
+      corObj <- stats::cor.test(x, y, method = method)
 
       # make sure all values have X-many decimal places
       cor_est <- as.numeric(corObj$estimate)
@@ -366,7 +382,6 @@ ggally_cor <- function(
   )
 }
 
-
 #' Generalized text display
 #'
 #' @param data data set using
@@ -384,23 +399,25 @@ ggally_cor <- function(
 #' @param align_percent relative align position of the text. When \code{title_hjust = 0.5} and \code{group_hjust = 0.5}, this should not be needed to be set.
 #' @param title_hjust,group_hjust \code{hjust} sent to \code{\link[ggplot2]{geom_text}()} for the title and group values respectively. Any \code{hjust} value supplied in \code{title_args} or \code{group_args} will take precedence.
 #' @seealso \code{\link{ggally_cor}}
+#' @importFrom dplyr arrange summarise
 #' @export
 ggally_statistic <- function(
-    data,
-    mapping,
-    text_fn,
-    title,
-    na.rm = NA,
-    display_grid = FALSE,
-    justify_labels = "right",
-    justify_text = "left",
-    sep = ": ",
-    family = "mono",
-    title_args = list(),
-    group_args = list(),
-    align_percent = 0.5,
-    title_hjust = 0.5,
-    group_hjust = 0.5) {
+  data,
+  mapping,
+  text_fn,
+  title,
+  na.rm = NA,
+  display_grid = FALSE,
+  justify_labels = "right",
+  justify_text = "left",
+  sep = ": ",
+  family = "mono",
+  title_args = list(),
+  group_args = list(),
+  align_percent = 0.5,
+  title_hjust = 0.5,
+  group_hjust = 0.5
+) {
   set_if_not_there <- function(obj, key, value) {
     obj <- as.list(obj)
     # if (! "family" %in% rlang::names2(obj)) {
@@ -420,7 +437,9 @@ ggally_statistic <- function(
   colorData <- eval_data_col(data, mapping$colour)
 
   if (is.numeric(colorData)) {
-    stop("`mapping` color column must be categorical, not numeric")
+    cli::cli_abort(
+      "{.arg mapping} color column must be categorical, not numeric"
+    )
   }
 
   display_na_rm <- is.na(na.rm)
@@ -444,9 +463,9 @@ ggally_statistic <- function(
       if (isTRUE(display_na_rm)) {
         total <- sum(!rows)
         if (total > 1) {
-          warning("Removed ", total, " rows containing missing values")
+          cli::cli_warn("Removed {.val {total}} rows containing missing values")
         } else if (total == 1) {
-          warning("Removing 1 row that contained a missing value")
+          cli::cli_warn("Removing 1 row that contained a missing value")
         }
       }
     }
@@ -477,19 +496,14 @@ ggally_statistic <- function(
 
   # if there is a color grouping...
   if (!is.null(colorData) && !inherits(colorData, "AsIs")) {
-    cord <- ddply(
-      data.frame(x = xData, y = yData, color = colorData),
-      "color",
-      function(dt) {
-        text_fn(dt$x, dt$y)
-      }
-    )
-    colnames(cord)[2] <- "text"
+    cord <- data.frame(x = xData, y = yData, color = colorData) |>
+      summarise(text = text_fn(.data$x, .data$y), .by = "color") |>
+      arrange(.data$color)
 
     # put in correct order
     lev <- levels(as.factor(colorData))
     ord <- rep(-1, nrow(cord))
-    for (i in 1:nrow(cord)) {
+    for (i in seq_len(nrow(cord))) {
       for (j in seq_along(lev)) {
         if (identical(as.character(cord$color[i]), as.character(lev[j]))) {
           ord[i] <- j
@@ -508,18 +522,20 @@ ggally_statistic <- function(
     # title
     ggally_text_args <- append(
       list(
-        label   = str_c(title, sep, text_fn(xVal, yVal)),
+        label = str_c(title, sep, text_fn(xVal, yVal)),
         mapping = mapping,
-        xP      = 0.5,
-        yP      = 0.9,
-        xrange  = xrange,
-        yrange  = yrange
+        xP = 0.5,
+        yP = 0.9,
+        xrange = xrange,
+        yrange = yrange
       ),
       title_args
     )
     p <- do.call(ggally_text, ggally_text_args)
 
-    xPos <- rep(align_percent, nrow(cord)) * diff(xrange) + min(xrange, na.rm = TRUE)
+    xPos <- rep(align_percent, nrow(cord)) *
+      diff(xrange) +
+      min(xrange, na.rm = TRUE)
     yPos <- seq(from = 0.9, to = 0.2, length.out = nrow(cord) + 1)
     yPos <- yPos * diff(yrange) + min(yrange, na.rm = TRUE)
     yPos <- yPos[-1]
@@ -532,10 +548,10 @@ ggally_statistic <- function(
       list(
         data = cordf,
         aes(
-          x = !!as.name("xPos"),
-          y = !!as.name("yPos"),
-          label = !!as.name("labelp"),
-          color = !!as.name("labelp")
+          x = .data$xPos,
+          y = .data$yPos,
+          label = .data$labelp,
+          color = .data$labelp
         )
       ),
       group_args
@@ -574,9 +590,6 @@ ggally_statistic <- function(
 }
 
 
-
-
-
 #' Box plot
 #'
 #' Make a box plot with a given data set. \code{ggally_box_no_facet} will be a single panel plot, while \code{ggally_box} will be a faceted plot
@@ -733,7 +746,6 @@ ggally_dot_and_box_no_facet <- function(data, mapping, ..., boxPlot = TRUE) {
 }
 
 
-
 #' Faceted histogram
 #'
 #' Display subsetted histograms of the data in different panels.
@@ -856,7 +868,7 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE) {
 
   xVal <- mapping_string(mapping$x)
   yVal <- mapping_string(mapping$y)
-  mappingY <- mapping$y # nolint
+  mappingY <- mapping$y
   mapping$y <- NULL # will be faceted
 
   p <- ggplot(data = data, mapping) +
@@ -865,7 +877,7 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE) {
   if (identical(den_strip, TRUE)) {
     p <- p +
       geom_histogram(
-        mapping = aes(fill = after_stat(!!as.name("density"))), # nolint
+        mapping = aes(fill = after_stat(!!as.name("density"))),
         position = "fill",
         ...
       ) +
@@ -877,7 +889,9 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE) {
     p <- p +
       stat_density(
         aes(
-          y = after_stat(!!as.name("scaled")) * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
+          y = after_stat(!!as.name("scaled")) *
+            diff(range(.data$x, na.rm = TRUE)) +
+            min(.data$x, na.rm = TRUE)
         ),
         position = "identity",
         geom = "line",
@@ -885,7 +899,6 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE) {
       )
   }
 
-
   if (horizontal) {
     p <- p + facet_grid(paste(yVal, " ~ .", sep = ""))
 
@@ -933,7 +946,9 @@ ggally_densityDiag <- function(data, mapping, ..., rescale = FALSE) {
     p <- p +
       stat_density(
         aes(
-          y = after_stat(!!as.name("scaled")) * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
+          y = after_stat(!!as.name("scaled")) *
+            diff(range(.data$x, na.rm = TRUE)) +
+            min(.data$x, na.rm = TRUE)
         ),
         position = "identity",
         geom = "line",
@@ -980,12 +995,19 @@ ggally_barDiag <- function(data, mapping, ..., rescale = FALSE) {
     # histBarPerc <- buildInfo$data[[1]]$ncount
   } else if (numer) {
     if (identical(rescale, TRUE)) {
-      p <- p + geom_histogram(
-        aes(
-          y = after_stat(!!as.name("density")) / max(after_stat(!!as.name("density"))) * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
-        ),
-        ...
-      ) + coord_cartesian(ylim = range(eval_data_col(data, mapping$x), na.rm = TRUE))
+      p <- p +
+        geom_histogram(
+          aes(
+            y = after_stat(!!as.name("density")) /
+              max(after_stat(!!as.name("density"))) *
+              diff(range(.data$x, na.rm = TRUE)) +
+              min(.data$x, na.rm = TRUE)
+          ),
+          ...
+        ) +
+        coord_cartesian(
+          ylim = range(eval_data_col(data, mapping$x), na.rm = TRUE)
+        )
     } else {
       p <- p + geom_histogram(...)
     }
@@ -1018,13 +1040,14 @@ ggally_barDiag <- function(data, mapping, ..., rescale = FALSE) {
 #' p_(ggally_text("Example 1"))
 #' p_(ggally_text("Example\nTwo", mapping = ggplot2::aes(size = 15), color = I("red")))
 ggally_text <- function(
-    label,
-    mapping = ggplot2::aes(color = I("black")),
-    xP = 0.5,
-    yP = 0.5,
-    xrange = c(0, 1),
-    yrange = c(0, 1),
-    ...) {
+  label,
+  mapping = ggplot2::aes(color = I("black")),
+  xP = 0.5,
+  yP = 0.5,
+  xrange = c(0, 1),
+  yrange = c(0, 1),
+  ...
+) {
   theme <- theme_get()
 
   p <- ggplot() +
@@ -1033,10 +1056,10 @@ ggally_text <- function(
     theme(
       panel.grid.minor = element_blank(),
       panel.grid.major = element_line(
-        colour = ifnull(theme$panel.background$fill, NA)
+        colour = theme$panel.background$fill %||% NA
       ),
       panel.background = element_rect(
-        fill = ifnull(theme$panel.grid.major$colour, NA)
+        fill = theme$panel.grid.major$colour %||% NA
       )
     ) +
     labs(x = NULL, y = NULL)
@@ -1060,8 +1083,8 @@ ggally_text <- function(
     p <- p +
       geom_text(label = label, mapping = mapping, ...)
   } else {
-    bg <- ifnull(theme$panel.background$fill, "grey92")
-    fg <- ifnull(theme$axis.text$colour, "gray30")
+    bg <- theme$panel.background$fill %||% "grey92"
+    fg <- theme$axis.text$colour %||% "gray30"
     colour <- scales::colour_ramp(c(bg, fg))(0.75)
     p <- p +
       geom_text(label = label, mapping = mapping, colour = colour, ...)
@@ -1160,18 +1183,21 @@ get_x_axis_labels <- function(p, xRange) {
 #' p_(ggally_diagAxis(tips, ggplot2::aes(x = tip)))
 #' p_(ggally_diagAxis(tips, ggplot2::aes(x = sex)))
 ggally_diagAxis <- function(
-    data,
-    mapping,
-    label = mapping$x,
-    labelSize = 5,
-    labelXPercent = 0.5,
-    labelYPercent = 0.55,
-    labelHJust = 0.5,
-    labelVJust = 0.5,
-    gridLabelSize = 4,
-    ...) {
+  data,
+  mapping,
+  label = mapping$x,
+  labelSize = 5,
+  labelXPercent = 0.5,
+  labelYPercent = 0.55,
+  labelHJust = 0.5,
+  labelVJust = 0.5,
+  gridLabelSize = 4,
+  ...
+) {
   if (is.null(mapping$x)) {
-    stop("mapping$x is null.  There must be a column value in this location.")
+    cli::cli_abort(
+      "mapping$x is null. There must be a column value in this location."
+    )
   }
   mapping$y <- NULL
   numer <- !is_horizontal(data, mapping, "x")
@@ -1191,66 +1217,69 @@ ggally_diagAxis <- function(
     # xrange <- c(xmin, xmax)
 
     p <- ggally_text(
-      label   = label,
+      label = label,
       mapping = aes(col = I("grey50")),
-      xrange  = xrange,
-      yrange  = xrange,
-      size    = labelSize,
-      xP      = labelXPercent,
-      yP      = labelYPercent,
-      hjust   = labelHJust,
-      vjust   = labelVJust
+      xrange = xrange,
+      yrange = xrange,
+      size = labelSize,
+      xP = labelXPercent,
+      yP = labelYPercent,
+      hjust = labelHJust,
+      vjust = labelVJust
     )
 
     axisBreaks <- get_x_axis_labels(p, xrange)
     # print(axisBreaks)
-    p <- p + geom_text(
-      data = axisBreaks,
-      mapping = aes(
-        x     = !!as.name("xPos"),
-        y     = !!as.name("yPos"),
-        label = !!as.name("lab"),
-        hjust = !!as.name("hjust"),
-        vjust = !!as.name("vjust")
-      ),
-      col = "grey50",
-      size = gridLabelSize
-    )
+    p <- p +
+      geom_text(
+        data = axisBreaks,
+        mapping = aes(
+          x = .data$xPos,
+          y = .data$yPos,
+          label = .data$lab,
+          hjust = .data$hjust,
+          vjust = .data$"vjust"
+        ),
+        col = "grey50",
+        size = gridLabelSize
+      )
   } else {
     breakLabels <- levels(as.factor(xData))
     numLvls <- length(breakLabels)
 
     p <- ggally_text(
-      label   = label,
+      label = label,
       mapping = aes(col = I("grey50")),
-      xrange  = c(0, 1),
-      yrange  = c(0, 1),
-      size    = labelSize,
-      yP      = labelYPercent,
-      xP      = labelXPercent,
-      hjust   = labelHJust,
-      vjust   = labelVJust
+      xrange = c(0, 1),
+      yrange = c(0, 1),
+      size = labelSize,
+      yP = labelYPercent,
+      xP = labelXPercent,
+      hjust = labelHJust,
+      vjust = labelVJust
     )
     # axisBreaks <- (1+2*0:(numLvls-1))/(2*numLvls)
-    axisBreaks <- 0:(numLvls - 1) * (0.125 + (1 - 0.125 * (numLvls - 1)) / numLvls) +
+    axisBreaks <- 0:(numLvls - 1) *
+      (0.125 + (1 - 0.125 * (numLvls - 1)) / numLvls) +
       (1 - 0.125 * (numLvls - 1)) / (2 * numLvls)
 
     axisLabs <- data.frame(
-      x   = axisBreaks[1:numLvls],
-      y   = axisBreaks[numLvls:1],
+      x = axisBreaks[1:numLvls],
+      y = axisBreaks[numLvls:1],
       lab = breakLabels
     )
 
-    p <- p + geom_text(
-      data = axisLabs,
-      mapping = aes(
-        x     = !!as.name("x"),
-        y     = !!as.name("y"),
-        label = !!as.name("lab")
-      ),
-      col = "grey50",
-      size = gridLabelSize
-    )
+    p <- p +
+      geom_text(
+        data = axisLabs,
+        mapping = aes(
+          x = .data$x,
+          y = .data$y,
+          label = .data$lab
+        ),
+        col = "grey50",
+        size = gridLabelSize
+      )
 
     # hack to remove warning message... cuz it doesn't listen to suppress messages
     p$scales$scales[[1]]$breaks <- axisBreaks
@@ -1319,45 +1348,60 @@ ggally_facetbar <- function(data, mapping, ...) {
 #'   tips, ggplot2::aes(sex, day),
 #'   floor = 20, ceiling = 50
 #' ) + ggplot2::theme(aspect.ratio = 4 / 2))
+#' @importFrom dplyr all_of arrange n pick summarise
 ggally_ratio <- function(
-    data,
-    mapping = ggplot2::aes(!!!stats::setNames(lapply(colnames(data)[1:2], as.name), c("x", "y"))),
-    ...,
-    floor = 0,
-    ceiling = NULL) {
+  data,
+  mapping = ggplot2::aes(
+    !!!stats::setNames(lapply(colnames(data)[1:2], as.name), c("x", "y"))
+  ),
+  ...,
+  floor = 0,
+  ceiling = NULL
+) {
   # capture the original names
   xName <- mapping_string(mapping$x)
   yName <- mapping_string(mapping$y)
 
-  countData <- plyr::count(data, vars = c(xName, yName))
-
-  # overwrite names so name clashes don't happen
-  colnames(countData)[1:2] <- c("x", "y")
+  countData <-
+    dplyr::count(
+      data,
+      xvar = .data[[xName]],
+      yvar = .data[[yName]],
+      name = "freq"
+    ) |>
+    rename(
+      x = "xvar",
+      y = "yvar"
+    )
 
   xNames <- levels(countData[["x"]])
   yNames <- levels(countData[["y"]])
 
-  countData <- subset(countData, freq >= floor)
+  countData <- countData[!is.na(countData$freq) & countData$freq >= floor, ]
 
-  if (is.null(ceiling)) {
-    ceiling <- max(countData$freq)
-  }
+  ceiling <- ceiling %||% max(countData$freq)
 
   countData[["freqSize"]] <- sqrt(pmin(countData[["freq"]], ceiling) / ceiling)
-  countData[["col"]] <- ifelse(countData[["freq"]] > ceiling, "grey30", "grey50")
+  countData[["col"]] <- ifelse(
+    countData[["freq"]] > ceiling,
+    "grey30",
+    "grey50"
+  )
 
-  countData[["xPos"]] <- as.numeric(countData[["x"]]) + (1 / 2) * countData[["freqSize"]]
-  countData[["yPos"]] <- as.numeric(countData[["y"]]) + (1 / 2) * countData[["freqSize"]]
+  countData[["xPos"]] <- as.numeric(countData[["x"]]) +
+    (1 / 2) * countData[["freqSize"]]
+  countData[["yPos"]] <- as.numeric(countData[["y"]]) +
+    (1 / 2) * countData[["freqSize"]]
 
   p <-
     ggplot(
       data = countData,
       mapping = aes(
-        x = !!as.name("xPos"),
-        y = !!as.name("yPos"),
-        height = !!as.name("freqSize"),
-        width = !!as.name("freqSize"),
-        fill = !!as.name("col")
+        x = .data$xPos,
+        y = .data$yPos,
+        height = .data$freqSize,
+        width = .data$freqSize,
+        fill = .data$col
       )
     ) +
     geom_tile(...) +
@@ -1394,7 +1438,6 @@ ggally_ratio <- function(
 }
 
 
-
 #' Display counts of observations
 #'
 #' Plot the number of observations by using rectangles
@@ -1427,8 +1470,12 @@ ggally_ratio <- function(
 #' ))
 ggally_count <- function(data, mapping, ...) {
   mapping <- mapping_color_to_fill(mapping)
-  if (is.null(mapping$x)) stop("'x' aesthetic is required.")
-  if (is.null(mapping$y)) stop("'y' aesthetic is required.")
+  if (is.null(mapping$x)) {
+    cli::cli_abort("{.field x} aesthetic is required.")
+  }
+  if (is.null(mapping$y)) {
+    cli::cli_abort("{.field y} aesthetic is required.")
+  }
   # for stat_ggally_count(), y should be mapped to base_y
   # and always be a factor
   count_col <- ".ggally_y"
@@ -1437,7 +1484,10 @@ ggally_count <- function(data, mapping, ...) {
   # Reverse the y axis here. I'd like to perform this in the
   # `scale_y_continuous(trans="reverse")`, but the trans is applied after
   # `breaks/labels`
-  data[[count_col]] <- factor(data[[count_col]], levels = rev(levels(data[[count_col]])))
+  data[[count_col]] <- factor(
+    data[[count_col]],
+    levels = rev(levels(data[[count_col]]))
+  )
 
   ylabel <- mapping_string(mapping$y)
   mapping$base_y <- aes(base_y = !!as.name(count_col))$base_y
@@ -1447,7 +1497,7 @@ ggally_count <- function(data, mapping, ...) {
   args <- list(...)
   if (!"fill" %in% names(args)) {
     if (is.null(mapping$fill)) {
-      args$fill <- GeomRect$default_aes$fill
+      args$fill <- get_geom_defaults(GeomRect)$fill
     }
   }
 
@@ -1469,22 +1519,25 @@ ggally_count <- function(data, mapping, ...) {
 # na.rm = TRUE to remove warnings if NA (cf. stat_count)
 # x.width to control size of tiles
 stat_ggally_count <- function(
-    mapping = NULL,
-    data = NULL,
-    geom = "tile", position = "identity",
-    ...,
-    x.width = .9,
-    na.rm = FALSE,
-    show.legend = NA,
-    inherit.aes = TRUE) {
+  mapping = NULL,
+  data = NULL,
+  geom = "tile",
+  position = "identity",
+  ...,
+  x.width = .9,
+  na.rm = FALSE,
+  show.legend = NA,
+  inherit.aes = TRUE
+) {
   params <- list(
     x.width = x.width,
     na.rm = na.rm,
     ...
   )
   if (!is.null(params$y)) {
-    stop("stat_ggally_count() must not be used with a y aesthetic,
-         but with a base_y aesthetic instead.", call. = FALSE)
+    cli::cli_abort(
+      "{.fn stat_ggally_count} must not be used with a {.field y} aesthetic, but with a {.field base_y} aesthetic instead."
+    )
   }
 
   layer(
@@ -1503,7 +1556,9 @@ stat_ggally_count <- function(
 #' @format NULL
 #' @usage NULL
 #' @export
-StatGGallyCount <- ggproto("StatGGallyCount", Stat,
+StatGGallyCount <- ggproto(
+  "StatGGallyCount",
+  Stat,
   required_aes = c("x", "base_y"),
   default_aes = aes(
     weight = 1,
@@ -1543,9 +1598,16 @@ StatGGallyCount <- ggproto("StatGGallyCount", Stat,
     panel$prop <- panel$n / panel$n_xy
     panel$width <- sqrt(panel$n_xy) / max(sqrt(panel$n_xy)) * x.width
     panel$height <- panel$width * panel$prop
-    panel$cum_height <- stats::ave(panel$height, panel$x, panel$base_y, FUN = cumsum)
-    panel$y <- as.numeric(panel$base_y) + panel$cum_height -
-      panel$height / 2 - panel$width / 2
+    panel$cum_height <- stats::ave(
+      panel$height,
+      panel$x,
+      panel$base_y,
+      FUN = cumsum
+    )
+    panel$y <- as.numeric(panel$base_y) +
+      panel$cum_height -
+      panel$height / 2 -
+      panel$width / 2
 
     panel
   }
@@ -1583,25 +1645,25 @@ ggally_blank <- function(...) {
   p <- ggplot(data = a, aes(x = !!as.name("X"), y = !!as.name("Y"))) +
     geom_point(colour = "transparent") +
     theme(
-      axis.line         = element_blank(),
-      axis.text.x       = element_blank(),
-      axis.text.y       = element_blank(),
-      axis.ticks        = element_blank(),
-      axis.title.x      = element_blank(),
-      axis.title.y      = element_blank(),
+      axis.line = element_blank(),
+      axis.text.x = element_blank(),
+      axis.text.y = element_blank(),
+      axis.ticks = element_blank(),
+      axis.title.x = element_blank(),
+      axis.title.y = element_blank(),
       legend.background = element_blank(),
-      legend.key        = element_blank(),
-      legend.text       = element_blank(),
-      legend.title      = element_blank(),
-      panel.background  = element_blank(),
-      panel.border      = element_blank(),
-      panel.grid.major  = element_blank(),
-      panel.grid.minor  = element_blank(),
-      plot.background   = element_blank(),
-      plot.title        = element_blank(),
-      strip.background  = element_blank(),
-      strip.text.x      = element_blank(),
-      strip.text.y      = element_blank()
+      legend.key = element_blank(),
+      legend.text = element_blank(),
+      legend.title = element_blank(),
+      panel.background = element_blank(),
+      panel.border = element_blank(),
+      panel.grid.major = element_blank(),
+      panel.grid.minor = element_blank(),
+      plot.background = element_blank(),
+      plot.title = element_blank(),
+      strip.background = element_blank(),
+      strip.text.x = element_blank(),
+      strip.text.y = element_blank()
     )
 
   class(p) <- c(class(p), "ggmatrix_blank")
@@ -1615,7 +1677,6 @@ ggally_blankDiag <- function(...) {
 }
 
 
-
 #' NA plot
 #'
 #' Draws a large \code{NA} in the middle of the plotting area.  This plot is useful when all X or Y data is \code{NA}
@@ -1628,31 +1689,40 @@ ggally_blankDiag <- function(...) {
 #' @param ... other arguments sent to geom_text
 #' @export
 #' @keywords hplot
-ggally_na <- function(data = NULL, mapping = NULL, size = 10, color = "grey20", ...) {
+ggally_na <- function(
+  data = NULL,
+  mapping = NULL,
+  size = 10,
+  color = "grey20",
+  ...
+) {
   a <- data.frame(x = 1, y = 1, label = "NA")
 
-  p <- ggplot(data = a, aes(x = !!as.name("X"), y = !!as.name("Y"), label = !!as.name("label"))) +
+  p <- ggplot(
+    data = a,
+    aes(x = !!as.name("X"), y = !!as.name("Y"), label = !!as.name("label"))
+  ) +
     geom_text(color = color, size = size, ...) +
     theme(
-      axis.line         = element_blank(),
-      axis.text.x       = element_blank(),
-      axis.text.y       = element_blank(),
-      axis.ticks        = element_blank(),
-      axis.title.x      = element_blank(),
-      axis.title.y      = element_blank(),
+      axis.line = element_blank(),
+      axis.text.x = element_blank(),
+      axis.text.y = element_blank(),
+      axis.ticks = element_blank(),
+      axis.title.x = element_blank(),
+      axis.title.y = element_blank(),
       legend.background = element_blank(),
-      legend.key        = element_blank(),
-      legend.text       = element_blank(),
-      legend.title      = element_blank(),
-      panel.background  = element_blank(),
-      panel.border      = element_blank(),
-      panel.grid.major  = element_blank(),
-      panel.grid.minor  = element_blank(),
-      plot.background   = element_blank(),
-      plot.title        = element_blank(),
-      strip.background  = element_blank(),
-      strip.text.x      = element_blank(),
-      strip.text.y      = element_blank()
+      legend.key = element_blank(),
+      legend.text = element_blank(),
+      legend.title = element_blank(),
+      panel.background = element_blank(),
+      panel.border = element_blank(),
+      panel.grid.major = element_blank(),
+      panel.grid.minor = element_blank(),
+      plot.background = element_blank(),
+      plot.title = element_blank(),
+      strip.background = element_blank(),
+      strip.text.x = element_blank(),
+      strip.text.y = element_blank()
     )
 
   p
@@ -1665,7 +1735,6 @@ ggally_naDiag <- function(...) {
 }
 
 
-
 #' Scatterplot for continuous and categorical variables
 #'
 #' Make scatterplots compatible with both continuous and categorical variables
@@ -1696,7 +1765,7 @@ ggally_naDiag <- function(...) {
 #'   diag = list(discrete = "autopointDiag", continuous = "autopointDiag")
 #' ))
 ggally_autopoint <- function(data, mapping, ...) {
-  require_namespaces("ggforce")
+  rlang::check_installed("ggforce")
 
   args <- list(...)
   if (!"alpha" %in% names(args) && is.null(mapping$alpha)) {
@@ -1756,28 +1825,31 @@ ggally_autopointDiag <- function(data, mapping, ...) {
 #'   }
 #'   p_(ggally_summarise_by(tips, mapping = aes(x = total_bill, y = day), text_fn = weighted_sum))
 #' }
+#' @importFrom dplyr arrange summarise
 ggally_summarise_by <- function(
-    data,
-    mapping,
-    text_fn = weighted_median_iqr,
-    text_fn_vertical = NULL,
-    ...) {
-  if (is.null(mapping$x)) stop("'x' aesthetic is required.")
-  if (is.null(mapping$y)) stop("'y' aesthetic is required.")
+  data,
+  mapping,
+  text_fn = weighted_median_iqr,
+  text_fn_vertical = NULL,
+  ...
+) {
+  if (is.null(mapping$x)) {
+    cli::cli_abort("{.field x} aesthetic is required.")
+  }
+  if (is.null(mapping$y)) {
+    cli::cli_abort("{.field y} aesthetic is required.")
+  }
 
   horizontal <- is_horizontal(data, mapping)
   if (horizontal) {
-    res <- ddply(
-      data.frame(
-        x = eval_data_col(data, mapping$x),
-        y = eval_data_col(data, mapping$y),
-        weight = eval_data_col(data, mapping$weight) %||% 1,
-        stringsAsFactors = FALSE
-      ),
-      c("y"),
-      plyr::here(summarize),
-      label = text_fn(x, weight)
-    )
+    res <- data.frame(
+      x = eval_data_col(data, mapping$x),
+      y = eval_data_col(data, mapping$y),
+      weight = eval_data_col(data, mapping$weight) %||% 1,
+      stringsAsFactors = FALSE
+    ) |>
+      summarise(label = text_fn(.data$x, .data$weight), .by = "y") |>
+      arrange(.data$y)
     # keep colour if matching the discrete variable
     if (mapping_string(mapping$colour) == mapping_string(mapping$y)) {
       col <- as.name("y")
@@ -1786,7 +1858,7 @@ ggally_summarise_by <- function(
     }
 
     ggplot(res) +
-      aes(y = !!as.name("y"), x = 1, label = !!as.name("label"), colour = !!col) +
+      aes(y = .data$y, x = 1, label = .data$label, colour = !!col) +
       geom_text(...) +
       xlab("") +
       ylab(mapping_string(mapping$y)) +
@@ -1810,7 +1882,12 @@ ggally_summarise_by <- function(
         gsub(" ", "\n", text_fn(x, weights))
       }
     }
-    ggally_summarise_by(data, mapping_swap_x_y(mapping), text_fn_vertical, ...) +
+    ggally_summarise_by(
+      data,
+      mapping_swap_x_y(mapping),
+      text_fn_vertical,
+      ...
+    ) +
       coord_flip() +
       theme(
         axis.ticks.y = element_blank(),
@@ -1829,8 +1906,16 @@ ggally_summarise_by <- function(
 #' \code{weighted_median_iqr} computes weighted median and interquartile range.
 #' @export
 weighted_median_iqr <- function(x, weights = NULL) {
-  require_namespaces("Hmisc")
-  s <- round(Hmisc::wtd.quantile(x, weights = weights, probs = c(.25, .5, .75), na.rm = TRUE), digits = 1)
+  rlang::check_installed("Hmisc")
+  s <- round(
+    Hmisc::wtd.quantile(
+      x,
+      weights = weights,
+      probs = c(.25, .5, .75),
+      na.rm = TRUE
+    ),
+    digits = 1
+  )
   paste0("Median: ", s[2], " [", s[1], "-", s[3], "]")
 }
 
@@ -1839,8 +1924,11 @@ weighted_median_iqr <- function(x, weights = NULL) {
 #' \code{weighted_mean_sd} computes weighted mean and standard deviation.
 #' @export
 weighted_mean_sd <- function(x, weights = NULL) {
-  require_namespaces("Hmisc")
+  rlang::check_installed("Hmisc")
   m <- round(Hmisc::wtd.mean(x, weights = weights, na.rm = TRUE), digits = 1)
-  sd <- round(sqrt(Hmisc::wtd.var(x, weights = weights, na.rm = TRUE)), digits = 1)
+  sd <- round(
+    sqrt(Hmisc::wtd.var(x, weights = weights, na.rm = TRUE)),
+    digits = 1
+  )
   paste0("Mean: ", m, " (", sd, ")")
 }
