@@ -56,20 +56,24 @@
 #' # outcome can be numerical
 #' p_(ggbivariate(tips, outcome = "tip", title = "tip"))
 ggbivariate <- function(
-    data,
-    outcome,
-    explanatory = NULL,
-    mapping = NULL, types = NULL,
-    ...,
-    rowbar_args = NULL) {
+  data,
+  outcome,
+  explanatory = NULL,
+  mapping = NULL,
+  types = NULL,
+  ...,
+  rowbar_args = NULL
+) {
   if (length(outcome) != 1) {
-    stop("You should provide only one `outcome`.")
+    cli::cli_abort("You should provide only one {.arg outcome}.")
   }
   if (is.numeric(outcome)) {
     outcome <- names(data)[outcome]
   }
   if (is.null(explanatory)) {
-    explanatory <- names(data)[!names(data) %in% c(outcome, mapping_string(mapping$weight))]
+    explanatory <- names(data)[
+      !names(data) %in% c(outcome, mapping_string(mapping$weight))
+    ]
   }
 
   if (!is.numeric(data[[outcome]])) {
