@@ -1,7 +1,3 @@
-if (getRversion() >= "2.15.1") {
-  utils::globalVariables(c("X1", "X2", "Y1", "Y2", "midX", "midY"))
-}
-
 #' Network plot
 #'
 #' Function for plotting network objects using \pkg{ggplot2}, with additional control
@@ -255,65 +251,68 @@ if (getRversion() >= "2.15.1") {
 #' p_(ggnet2(flo, label = TRUE, size = 12, color = "white"))
 ggnet2 <- function(
   net,
-  mode             = "fruchtermanreingold",
-  layout.par       = NULL,
-  layout.exp       = 0,
-  alpha            = 1,
-  color            = "grey75",
-  shape            = 19,
-  size             = 9,
-  max_size         = 9,
-  na.rm            = NA,
-  palette          = NULL,
-  alpha.palette    = NULL,
-  alpha.legend     = NA,
-  color.palette    = palette,
-  color.legend     = NA,
-  shape.palette    = NULL,
-  shape.legend     = NA,
-  size.palette     = NULL,
-  size.legend      = NA,
-  size.zero        = FALSE,
-  size.cut         = FALSE,
-  size.min         = NA,
-  size.max         = NA,
-  label            = FALSE,
-  label.alpha      = 1,
-  label.color      = "black",
-  label.size       = max_size / 2,
-  label.trim       = FALSE,
-  node.alpha       = alpha,
-  node.color       = color,
-  node.label       = label,
-  node.shape       = shape,
-  node.size        = size,
-  edge.alpha       = 1,
-  edge.color       = "grey50",
-  edge.lty         = "solid",
-  edge.size        = .25,
-  edge.label       = NULL,
+  mode = "fruchtermanreingold",
+  layout.par = NULL,
+  layout.exp = 0,
+  alpha = 1,
+  color = "grey75",
+  shape = 19,
+  size = 9,
+  max_size = 9,
+  na.rm = NA,
+  palette = NULL,
+  alpha.palette = NULL,
+  alpha.legend = NA,
+  color.palette = palette,
+  color.legend = NA,
+  shape.palette = NULL,
+  shape.legend = NA,
+  size.palette = NULL,
+  size.legend = NA,
+  size.zero = FALSE,
+  size.cut = FALSE,
+  size.min = NA,
+  size.max = NA,
+  label = FALSE,
+  label.alpha = 1,
+  label.color = "black",
+  label.size = max_size / 2,
+  label.trim = FALSE,
+  node.alpha = alpha,
+  node.color = color,
+  node.label = label,
+  node.shape = shape,
+  node.size = size,
+  edge.alpha = 1,
+  edge.color = "grey50",
+  edge.lty = "solid",
+  edge.size = .25,
+  edge.label = NULL,
   edge.label.alpha = 1,
   edge.label.color = label.color,
-  edge.label.fill  = "white",
-  edge.label.size  = max_size / 2,
-  arrow.size       = 0,
-  arrow.gap        = 0,
-  arrow.type       = "closed",
-  legend.size      = 9,
-  legend.position  = "right",
+  edge.label.fill = "white",
+  edge.label.size = max_size / 2,
+  arrow.size = 0,
+  arrow.gap = 0,
+  arrow.type = "closed",
+  legend.size = 9,
+  legend.position = "right",
   ...
 ) {
-
   # -- packages ----------------------------------------------------------------
 
-  require_namespaces(c("network", "sna", "scales"))
+  rlang::check_installed(c("network", "sna", "scales"))
 
   # -- conversion to network class ---------------------------------------------
 
-  if (inherits(net, "igraph") && "intergraph" %in% rownames(installed.packages())) {
+  if (
+    inherits(net, "igraph") && "intergraph" %in% rownames(installed.packages())
+  ) {
     net = intergraph::asNetwork(net)
   } else if (inherits(net, "igraph")) {
-    stop("install the 'intergraph' package to use igraph objects with ggnet2")
+    cli::cli_abort(
+      "install the {.fn intergraph} package to use {.pkg igraph} objects with {.fn ggnet2}"
+    )
   }
 
   if (!network::is.network(net)) {
@@ -321,7 +320,7 @@ ggnet2 <- function(
   }
 
   if (!network::is.network(net)) {
-    stop("could not coerce net to a network object")
+    cli::cli_abort("could not coerce {.arg net} to a {.pkg network} object")
   }
 
   # -- network functions -------------------------------------------------------
@@ -329,20 +328,22 @@ ggnet2 <- function(
   get_v = get("%v%", envir = getNamespace("network"))
   get_e = get("%e%", envir = getNamespace("network"))
 
-  set_mode = function(x, mode = network::get.network.attribute(x, "bipartite")) {
+  set_mode = function(
+    x,
+    mode = network::get.network.attribute(x, "bipartite")
+  ) {
     c(rep("actor", mode), rep("event", n_nodes - mode))
   }
 
   set_node = function(x, value, mode = TRUE) {
-
     if (is.null(x) || any(is.na(x)) || any(is.infinite(x)) || any(is.nan(x))) {
-      stop(paste("incorrect", value, "value"))
+      cli::cli_abort("incorrect {value} value")
     } else if (is.numeric(x) && any(x < 0)) {
-      stop(paste("incorrect", value, "value"))
+      cli::cli_abort("incorrect {value} value")
     } else if (length(x) == n_nodes) {
       x
     } else if (length(x) > 1) {
-      stop(paste("incorrect", value, "length"))
+      cli::cli_abort("incorrect {value} length")
     } else if (any(x %in% v_attr)) {
       get_v(net, x)
     } else if (mode && identical(x, "mode") && is_bip) {
@@ -350,60 +351,55 @@ ggnet2 <- function(
     } else {
       x
     }
-
   }
 
   set_edge = function(x, value) {
-
     if (is.null(x) || any(is.na(x)) || any(is.infinite(x)) || any(is.nan(x))) {
-      stop(paste("incorrect", value, "value"))
+      cli::cli_abort("incorrect {value} value")
     } else if (is.numeric(x) && any(x < 0)) {
-      stop(paste("incorrect", value, "value"))
+      cli::cli_abort("incorrect {value} value")
     } else if (length(x) == n_edges) {
       x
     } else if (length(x) > 1) {
-      stop(paste("incorrect", value, "length"))
+      cli::cli_abort("incorrect {value} length")
     } else if (any(x %in% e_attr)) {
       get_e(net, x)
     } else {
       x
     }
-
   }
 
   set_attr = function(x) {
-
     if (length(x) == n_nodes) {
       x
     } else if (length(x) > 1) {
-      stop(paste("incorrect coordinates length"))
+      cli::cli_abort("incorrect coordinates length")
     } else if (!x %in% v_attr) {
-      stop(paste("vertex attribute", x, "was not found"))
+      cli::cli_abort("vertex attribute {x} was not found")
     } else if (!is.numeric(get_v(net, x))) {
-      stop(paste("vertex attribute", x, "is not numeric"))
+      cli::cli_abort("vertex attribute {x} is not numeric")
     } else {
       get_v(net, x)
     }
-
   }
 
   set_name = function(x, y) {
-
     z = length(x) == 1 && x %in% v_attr
     z = ifelse(is.na(y), z, y)
     z = ifelse(isTRUE(z), x, z)
     ifelse(is.logical(z), "", z)
-
   }
 
   set_size = function(x) {
-
     y = x + (0 %in% x) * !size.zero
     y = scales::rescale_max(y)
     y = scales::abs_area(max_size)(y)
-    if (is.null(names(x))) names(y) = x else names(y) = names(x)
+    if (is.null(names(x))) {
+      names(y) = x
+    } else {
+      names(y) = names(x)
+    }
     y
-
   }
 
   is_one = function(x) length(unique(x)) == 1
@@ -421,29 +417,29 @@ ggnet2 <- function(
   is_dir = ifelse(network::is.directed(net), "digraph", "graph")
 
   if (!is.numeric(arrow.size) || arrow.size < 0) {
-    stop("incorrect arrow.size value")
+    cli::cli_abort("incorrect {.arg arrow.size} value")
   } else if (arrow.size > 0 && is_dir == "graph") {
-    warning("network is undirected; arrow.size ignored")
+    cli::cli_warn("network is undirected; {.arg arrow.size} ignored")
     arrow.size = 0
   }
 
   if (!is.numeric(arrow.gap) || arrow.gap < 0 || arrow.gap > 1) {
-    stop("incorrect arrow.gap value")
+    cli::cli_abort("incorrect {.arg arrow.gap} value")
   } else if (arrow.gap > 0 && is_dir == "graph") {
-    warning("network is undirected; arrow.gap ignored")
+    cli::cli_warn("network is undirected; {.arg arrow.gap} ignored")
     arrow.gap = 0
   }
 
   if (network::is.hyper(net)) {
-    stop("ggnet2 cannot plot hyper graphs")
+    cli::cli_abort("{.fn ggnet2} cannot plot hyper graphs")
   }
 
   if (network::is.multiplex(net)) {
-    stop("ggnet2 cannot plot multiplex graphs")
+    cli::cli_abort("{.fn ggnet2} cannot plot multiplex graphs")
   }
 
   if (network::has.loops(net)) {
-    warning("ggnet2 does not know how to handle self-loops")
+    cli::cli_warn("{.fn ggnet2} does not know how to handle self-loops")
   }
 
   # -- check max_size ----------------------------------------------------------
@@ -451,68 +447,75 @@ ggnet2 <- function(
   x = max_size
 
   if (!is.numeric(x) || is.infinite(x) || is.nan(x) || x < 0) {
-    stop("incorrect max_size value")
+    cli::cli_abort("incorrect {.arg max_size} value")
   }
 
   # -- initialize dataset ------------------------------------------------------
 
-  data = data.frame(label = get_v(net, "vertex.names"), stringsAsFactors = FALSE)
+  data = data.frame(
+    label = get_v(net, "vertex.names"),
+    stringsAsFactors = FALSE
+  )
 
-  data$alpha = set_node(node.alpha , "node.alpha")
-  data$color = set_node(node.color , "node.color")
-  data$shape = set_node(node.shape , "node.shape")
-  data$size  = set_node(node.size  , "node.size")
+  data$alpha = set_node(node.alpha, "node.alpha")
+  data$color = set_node(node.color, "node.color")
+  data$shape = set_node(node.shape, "node.shape")
+  data$size = set_node(node.size, "node.size")
 
   # -- node removal ------------------------------------------------------------
 
   if (length(na.rm) > 1) {
-    stop("incorrect na.rm value")
+    cli::cli_abort("incorrect {.arg na.rm} value")
   } else if (!is.na(na.rm)) {
-
     if (!na.rm %in% v_attr) {
-
-      stop(paste("vertex attribute", na.rm, "was not found"))
-
+      cli::cli_abort("vertex attribute {na.rm} was not found")
     }
 
     x = which(is.na(get_v(net, na.rm)))
-    message(paste("na.rm removed", length(x), "nodes out of", nrow(data)))
+    cli::cli_inform(
+      "{.arg na.rm} removed {length(x)} nodes out of {nrow(data)}"
+    )
 
     if (length(x) > 0) {
-
       data = data[-x, ]
       network::delete.vertices(net, x)
 
       if (!nrow(data)) {
-
-        warning("na.rm removed all nodes; nothing left to plot")
+        cli::cli_warn("{.arg na.rm} removed all nodes; nothing left to plot")
         return(invisible(NULL))
-
       }
-
     }
-
   }
 
   # -- weight methods ----------------------------------------------------------
 
   x = size
 
-  if (length(x) == 1 && x %in% c("indegree", "outdegree", "degree", "freeman")) {
-
+  if (
+    length(x) == 1 && x %in% c("indegree", "outdegree", "degree", "freeman")
+  ) {
     # prevent namespace conflict with igraph
     if ("package:igraph" %in% search()) {
-
       y = ifelse(is_dir == "digraph", "directed", "undirected")
-      z = c("indegree" = "in", "outdegree" = "out", "degree" = "all", "freeman" = "all")[x]
-      data$size = igraph::degree(igraph_graph_adjacency_matrix(as.matrix(net), mode = y), mode = z)
-
+      z = c(
+        "indegree" = "in",
+        "outdegree" = "out",
+        "degree" = "all",
+        "freeman" = "all"
+      )[x]
+      data$size = igraph::degree(
+        igraph_graph_adjacency_matrix(as.matrix(net), mode = y),
+        mode = z
+      )
     } else {
-      data$size = sna::degree(net, gmode = is_dir, cmode = ifelse(x == "degree", "freeman", x))
+      data$size = sna::degree(
+        net,
+        gmode = is_dir,
+        cmode = ifelse(x == "degree", "freeman", x)
+      )
     }
 
     size.legend = ifelse(is.na(size.legend), x, size.legend)
-
   }
 
   # -- weight thresholds -------------------------------------------------------
@@ -520,55 +523,47 @@ ggnet2 <- function(
   x = ifelse(is.na(size.min), 0, size.min)
 
   if (length(x) > 1 || !is.numeric(x) || is.infinite(x) || is.nan(x) || x < 0) {
-    stop("incorrect size.min value")
+    cli::cli_abort("incorrect {.arg size.min} value")
   } else if (x > 0 && !is.numeric(data$size)) {
-    warning("node.size is not numeric; size.min ignored")
+    cli::cli_warn("{.arg node.size} is not numeric; {.arg size.min} ignored")
   } else if (x > 0) {
-
     x = which(data$size < x)
-    message(paste("size.min removed", length(x), "nodes out of", nrow(data)))
+    cli::cli_inform(
+      "{.arg size.min} removed {length(x)} nodes out of {nrow(data)}"
+    )
 
     if (length(x) > 0) {
-
       data = data[-x, ]
       network::delete.vertices(net, x)
 
       if (!nrow(data)) {
-
-        warning("size.min removed all nodes; nothing left to plot")
+        cli::cli_warn("{.arg size.min} removed all nodes; nothing left to plot")
         return(invisible(NULL))
-
       }
-
     }
-
   }
 
   x = ifelse(is.na(size.max), 0, size.max)
 
   if (length(x) > 1 || !is.numeric(x) || is.infinite(x) || is.nan(x) || x < 0) {
-    stop("incorrect size.max value")
+    cli::cli_abort("incorrect {.arg size.max} value")
   } else if (x > 0 && !is.numeric(data$size)) {
-    warning("node.size is not numeric; size.max ignored")
+    cli::cli_warn("{.arg node.size} is not numeric; {.arg size.max} ignored")
   } else if (x > 0) {
-
     x = which(data$size > x)
-    message(paste("size.max removed", length(x), "nodes out of", nrow(data)))
+    cli::cli_inform(
+      "{.arg size.max} removed {length(x)} nodes out of {nrow(data)}"
+    )
 
     if (length(x) > 0) {
-
       data = data[-x, ]
       network::delete.vertices(net, x)
 
       if (!nrow(data)) {
-
-        warning("size.max removed all nodes; nothing left to plot")
+        cli::cli_warn("{.arg size.max} removed all nodes; nothing left to plot")
         return(invisible(NULL))
-
       }
-
     }
-
   }
 
   # -- weight quantiles --------------------------------------------------------
@@ -576,27 +571,25 @@ ggnet2 <- function(
   x = size.cut
 
   if (length(x) > 1 || is.null(x) || is.na(x) || is.infinite(x) || is.nan(x)) {
-    stop("incorrect size.cut value")
+    cli::cli_abort("incorrect {.arg size.cut} value")
   } else if (isTRUE(x)) {
     x = 4
   } else if (is.logical(x) && !x) {
     x = 0
   } else if (!is.numeric(x)) {
-    stop("incorrect size.cut value")
+    cli::cli_abort("incorrect {.arg size.cut} value")
   }
 
   if (x >= 1 && !is.numeric(data$size)) {
-    warning("node.size is not numeric; size.cut ignored")
+    cli::cli_warn("{.arg node.size} is not numeric; {.arg size.cut} ignored")
   } else if (x >= 1) {
-
     x = unique(quantile(data$size, probs = seq(0, 1, by = 1 / as.integer(x))))
 
     if (length(x) > 1) {
       data$size = cut(data$size, unique(x), include.lowest = TRUE)
     } else {
-      warning("node.size is invariant; size.cut ignored")
+      cli::cli_warn("{.arg node.size} is invariant; {.arg size.cut} ignored")
     }
-
   }
 
   # -- alpha palette -----------------------------------------------------------
@@ -610,19 +603,15 @@ ggnet2 <- function(
   }
 
   if (!is.null(names(x))) {
-
     y = unique(na.omit(data$alpha[!data$alpha %in% names(x)]))
 
     if (length(y) > 0) {
-      stop(paste("no alpha.palette value for", paste0(y, collapse = ", ")))
+      cli::cli_abort("no {.arg alpha.palette} value for {y}")
     }
-
   } else if (is.factor(data$alpha) || !is.numeric(x)) {
-
     data$alpha = factor(data$alpha)
     x = scales::rescale_max(1:length(levels(data$alpha)))
     names(x) = levels(data$alpha)
-
   }
 
   alpha.palette = x
@@ -637,43 +626,39 @@ ggnet2 <- function(
     x = unique(data$color)
   }
 
-  if (length(x) == 1 && "RColorBrewer" %in% rownames(installed.packages()) &&
-      x %in% rownames(RColorBrewer::brewer.pal.info)) {
-
+  if (
+    length(x) == 1 &&
+      "RColorBrewer" %in% rownames(installed.packages()) &&
+      x %in% rownames(RColorBrewer::brewer.pal.info)
+  ) {
     data$color = factor(data$color)
 
     n_groups = length(levels(data$color))
     n_colors = RColorBrewer::brewer.pal.info[x, "maxcolors"]
 
     if (n_groups > n_colors) {
-
-      stop(paste0("too many node groups (", n_groups, ") for ",
-                  "ColorBrewer palette ", x, " (max: ", n_colors, ")"))
-
+      cli::cli_abort(
+        "too many node groups ({n_groups}) for ColorBrewer palette {x} (max: {n_colors})"
+      )
     } else if (n_groups < 3) {
       n_groups = 3
     }
 
     x = RColorBrewer::brewer.pal(n_groups, x)[1:length(levels(data$color))]
     names(x) = levels(data$color)
-
   }
 
   if (!is.null(names(x))) {
-
     y = unique(na.omit(data$color[!data$color %in% names(x)]))
 
     if (length(y) > 0) {
-      stop(paste("no color.palette value for", paste0(y, collapse = ", ")))
+      cli::cli_abort("no {.arg color.palette} value for {y}")
     }
-
   } else if (is.factor(data$color) || !is_col(x)) {
-
     data$color = factor(data$color)
 
     x = gray.colors(length(x))
     names(x) = levels(data$color)
-
   }
 
   color.palette = x
@@ -689,19 +674,15 @@ ggnet2 <- function(
   }
 
   if (!is.null(names(x))) {
-
     y = unique(na.omit(data$shape[!data$shape %in% names(x)]))
 
     if (length(y) > 0) {
-      stop(paste("no shape.palette value for", paste0(y, collapse = ", ")))
+      cli::cli_abort("no {.arg shape.palette} value for {y}")
     }
-
   } else if (is.factor(data$shape) || !is.numeric(x)) {
-
     data$shape = factor(data$shape)
     x = scales::shape_pal()(length(levels(data$shape)))
     names(x) = levels(data$shape)
-
   }
 
   shape.palette = x
@@ -717,19 +698,15 @@ ggnet2 <- function(
   }
 
   if (!is.null(names(x))) {
-
     y = unique(na.omit(data$size[!data$size %in% names(x)]))
 
     if (length(y) > 0) {
-      stop(paste("no size.palette value for", paste0(y, collapse = ", ")))
+      cli::cli_abort("no {.arg size.palette} value for {y}")
     }
-
   } else if (is.factor(data$size) || !is.numeric(x)) {
-
     data$size = factor(data$size)
     x = 1:length(levels(data$size))
     names(x) = levels(data$size)
-
   }
 
   size.palette = x
@@ -751,10 +728,9 @@ ggnet2 <- function(
   # -- node placement ----------------------------------------------------------
 
   if (is.character(mode) && length(mode) == 1) {
-
     mode = paste0("gplot.layout.", mode)
     if (!exists(mode, where = getNamespace("sna"))) {
-      stop(paste("unsupported placement method:", mode))
+      cli::cli_abort("unsupported placement method: {.code {mode}}")
     } else {
       mode <- get(mode, getNamespace("sna"))
     }
@@ -763,21 +739,14 @@ ggnet2 <- function(
     xy = network::as.matrix.network.adjacency(net)
     xy = do.call(mode, list(xy, layout.par))
     xy = data.frame(x = xy[, 1], y = xy[, 2])
-
   } else if (is.character(mode) && length(mode) == 2) {
-
     # fixed coordinates from vertex attributes
     xy = data.frame(x = set_attr(mode[1]), y = set_attr(mode[2]))
-
   } else if (is.numeric(mode) && is.matrix(mode)) {
-
     # fixed coordinates from matrix
     xy = data.frame(x = set_attr(mode[, 1]), y = set_attr(mode[, 2]))
-
   } else {
-
-    stop("incorrect mode value")
-
+    cli::cli_abort("incorrect {.arg mode} value")
   }
 
   xy$x = scale(xy$x, min(xy$x), diff(range(xy$x)))[, 1]
@@ -790,10 +759,12 @@ ggnet2 <- function(
   edges = network::as.matrix.network.edgelist(net)
 
   if (edge.color[1] == "color" && length(edge.color) == 2) {
-
     # edge colors from node source and target
-    edge.color = ifelse(data$color[edges[, 1]] == data$color[edges[, 2]],
-                        as.character(data$color[edges[, 1]]), edge.color[2])
+    edge.color = ifelse(
+      data$color[edges[, 1]] == data$color[edges[, 2]],
+      as.character(data$color[edges[, 1]]),
+      edge.color[2]
+    )
 
     if (!is.null(names(color.palette))) {
       x = which(edge.color %in% names(color.palette))
@@ -801,13 +772,12 @@ ggnet2 <- function(
     }
 
     edge.color[is.na(edge.color)] = edge.color[2]
-
   }
 
   edge.color = set_edge(edge.color, "edge.color")
 
   if (!is_col(edge.color)) {
-    stop("incorrect edge.color value")
+    cli::cli_abort("incorrect {.arg edge.color} value")
   }
 
   # -- edge list ---------------------------------------------------------------
@@ -818,7 +788,6 @@ ggnet2 <- function(
   # -- edge labels, colors and sizes -------------------------------------------
 
   if (!is.null(edge.label)) {
-
     edges$midX = (edges$X1 + edges$X2) / 2
     edges$midY = (edges$Y1 + edges$Y2) / 2
     edges$label = set_edge(edge.label, "edge.label")
@@ -826,21 +795,20 @@ ggnet2 <- function(
     edge.label.alpha = set_edge(edge.label.alpha, "edge.label.alpha")
 
     if (!is.numeric(edge.label.alpha)) {
-      stop("incorrect edge.label.alpha value")
+      cli::cli_abort("incorrect {.arg edge.label.alpha} value")
     }
 
     edge.label.color = set_edge(edge.label.color, "edge.label.color")
 
     if (!is_col(edge.label.color)) {
-      stop("incorrect edge.label.color value")
+      cli::cli_abort("incorrect {.arg edge.label.color} value")
     }
 
     edge.label.size = set_edge(edge.label.size, "edge.label.size")
 
     if (!is.numeric(edge.label.size)) {
-      stop("incorrect edge.label.size value")
+      cli::cli_abort("incorrect {.arg edge.label.size} value")
     }
-
   }
 
   # -- edge linetype -----------------------------------------------------------
@@ -852,64 +820,57 @@ ggnet2 <- function(
   edge.size = set_edge(edge.size, "edge.size")
 
   if (!is.numeric(edge.size) || any(edge.size <= 0)) {
-    stop("incorrect edge.size value")
+    cli::cli_abort("incorrect {.arg edge.size} value")
   }
 
   # -- plot edges --------------------------------------------------------------
 
-  p = ggplot(data, aes(x = x, y = y))
+  p = ggplot(data, aes(x = .data$x, y = .data$y))
 
   if (nrow(edges) > 0) {
-
     if (arrow.gap > 0) {
-
       x.dir = with(edges, (X2 - X1)) # do not use absolute value
       y.dir = with(edges, (Y2 - Y1))
 
-      arrow.gap = with(edges, arrow.gap / sqrt(x.dir ^ 2 + y.dir ^ 2))
-
-      edges = transform(edges,
-                        X1 = X1 + arrow.gap * x.dir,
-                        Y1 = Y1 + arrow.gap * y.dir,
-                        X2 = X1 + (1 - arrow.gap) * x.dir,
-                        Y2 = Y1 + (1 - arrow.gap) * y.dir)
+      arrow.gap = with(edges, arrow.gap / sqrt(x.dir^2 + y.dir^2))
 
+      edges$X1 = edges$X1 + arrow.gap * x.dir
+      edges$Y1 = edges$Y1 + arrow.gap * y.dir
+      edges$X2 = edges$X1 + (1 - arrow.gap) * x.dir
+      edges$Y2 = edges$Y1 + (1 - arrow.gap) * y.dir
     }
 
     p = p +
       geom_segment(
         data = edges,
-        aes(x = X1, y = Y1, xend = X2, yend = Y2),
-        linewidth   = edge.size,
-        color  = edge.color,
-        alpha  = edge.alpha,
-        lty    = edge.lty,
-        arrow  = arrow(
-          type   = arrow.type,
+        aes(x = .data$X1, y = .data$Y1, xend = .data$X2, yend = .data$Y2),
+        linewidth = edge.size,
+        color = edge.color,
+        alpha = edge.alpha,
+        lty = edge.lty,
+        arrow = arrow(
+          type = arrow.type,
           length = unit(arrow.size, "pt")
         )
       )
-
   }
 
   if (nrow(edges) > 0 && !is.null(edge.label)) {
-
     p = p +
       geom_point(
         data = edges,
-        aes(x = midX, y = midY),
-        alpha  = edge.alpha,
-        color  = edge.label.fill,
-        size   = edge.label.size * 1.5
+        aes(x = .data$midX, y = .data$midY),
+        alpha = edge.alpha,
+        color = edge.label.fill,
+        size = edge.label.size * 1.5
       ) +
       geom_text(
         data = edges,
-        aes(x = midX, y = midY, label = label),
-        alpha  = edge.label.alpha,
-        color  = edge.label.color,
-        size   = edge.label.size
+        aes(x = .data$midX, y = .data$midY, label = label),
+        alpha = edge.label.alpha,
+        color = edge.label.color,
+        size = edge.label.size
       )
-
   }
 
   # -- plot nodes --------------------------------------------------------------
@@ -935,66 +896,68 @@ ggnet2 <- function(
   }
 
   p = p +
-    geom_point(aes(alpha = factor(alpha), color = factor(color),
-                   shape = factor(shape), size = factor(size)))
+    geom_point(aes(
+      alpha = factor(alpha),
+      color = factor(color),
+      shape = factor(shape),
+      size = factor(size)
+    ))
 
   # -- legend: alpha -----------------------------------------------------------
 
   if (is.numeric(data$alpha)) {
-
     v_alpha = unique(data$alpha)
     names(v_alpha) = unique(data$alpha)
 
     p = p +
-      scale_alpha_manual("", values = v_alpha) + guides(alpha = "none")
-
+      scale_alpha_manual("", values = v_alpha) +
+      guides(alpha = "none")
   } else {
-
     p = p +
-      scale_alpha_manual(set_name(node.alpha, alpha.legend),
-                         values = alpha.palette,
-                         breaks = names(alpha.palette),
-                         guide = guide_legend(override.aes = x))
-
+      scale_alpha_manual(
+        set_name(node.alpha, alpha.legend),
+        values = alpha.palette,
+        breaks = names(alpha.palette),
+        guide = guide_legend(override.aes = x)
+      )
   }
 
   # -- legend: color -----------------------------------------------------------
 
   if (!is.null(names(color.palette))) {
-
     p = p +
-      scale_color_manual(set_name(node.color, color.legend),
-                         values = color.palette,
-                         breaks = names(color.palette),
-                         guide = guide_legend(override.aes = x))
-
+      scale_color_manual(
+        set_name(node.color, color.legend),
+        values = color.palette,
+        breaks = names(color.palette),
+        guide = guide_legend(override.aes = x)
+      )
   } else {
-
     v_color = unique(data$color)
     names(v_color) = unique(data$color)
 
     p = p +
-      scale_color_manual("", values = v_color) + guides(color = "none")
-
+      scale_color_manual("", values = v_color) +
+      guides(color = "none")
   }
 
   # -- legend: shape -----------------------------------------------------------
 
   if (is.numeric(data$shape)) {
-
     v_shape = unique(data$shape)
     names(v_shape) = unique(data$shape)
 
     p = p +
-      scale_shape_manual("", values = v_shape) + guides(shape = "none")
-
+      scale_shape_manual("", values = v_shape) +
+      guides(shape = "none")
   } else {
-
     p = p +
-      scale_shape_manual(set_name(node.shape, shape.legend),
-                         values = shape.palette,
-                         breaks = names(shape.palette),
-                         guide = guide_legend(override.aes = x))
+      scale_shape_manual(
+        set_name(node.shape, shape.legend),
+        values = shape.palette,
+        breaks = names(shape.palette),
+        guide = guide_legend(override.aes = x)
+      )
   }
 
   # -- legend: size ------------------------------------------------------------
@@ -1002,59 +965,57 @@ ggnet2 <- function(
   x = x[names(x) != "size"]
 
   if (is.numeric(data$size)) {
-
     v_size = set_size(unique(data$size))
 
     if (length(v_size) == 1) {
-
       v_size = as.numeric(names(v_size))
       p = p +
-        scale_size_manual("", values = v_size) + guides(size = "none")
-
+        scale_size_manual("", values = v_size) +
+        guides(size = "none")
     } else {
-
       p = p +
-        scale_size_manual(set_name(node.size, size.legend),
-                          values = v_size,
-                          guide = guide_legend(override.aes = x))
-
+        scale_size_manual(
+          set_name(node.size, size.legend),
+          values = v_size,
+          guide = guide_legend(override.aes = x)
+        )
     }
-
   } else {
-
     p = p +
-      scale_size_manual(set_name(node.size, size.legend),
-                        values = set_size(size.palette),
-                        guide = guide_legend(override.aes = x))
-
+      scale_size_manual(
+        set_name(node.size, size.legend),
+        values = set_size(size.palette),
+        guide = guide_legend(override.aes = x)
+      )
   }
 
   # -- plot node labels --------------------------------------------------------
 
   if (!is_one(l) || unique(l) != "") {
-
     label.alpha = set_node(label.alpha, "label.alpha", mode = FALSE)
 
     if (!is.numeric(label.alpha)) {
-      stop("incorrect label.alpha value")
+      cli::cli_abort("incorrect {.arg label.alpha} value")
     }
 
     label.color = set_node(label.color, "label.color", mode = FALSE)
 
     if (!is_col(label.color)) {
-      stop("incorrect label.color value")
+      cli::cli_abort("incorrect {.arg label.color} value")
     }
 
     label.size = set_node(label.size, "label.size", mode = FALSE)
 
     if (!is.numeric(label.size)) {
-      stop("incorrect label.size value")
+      cli::cli_abort("incorrect {.arg label.size} value")
     }
 
     x = label.trim
 
-    if (length(x) > 1 || (!is.logical(x) && !is.numeric(x) && !is.function(x))) {
-      stop("incorrect label.trim value")
+    if (
+      length(x) > 1 || (!is.logical(x) && !is.numeric(x) && !is.function(x))
+    ) {
+      cli::cli_abort("incorrect {.arg label.trim} value")
     } else if (is.numeric(x) && x > 0) {
       l = substr(l, 1, x)
     } else if (is.function(x)) {
@@ -1066,10 +1027,9 @@ ggnet2 <- function(
         label = l,
         alpha = label.alpha,
         color = label.color,
-        size  = label.size,
+        size = label.size,
         ...
       )
-
   }
 
   # -- horizontal scale expansion ----------------------------------------------
@@ -1077,7 +1037,7 @@ ggnet2 <- function(
   x = range(data$x)
 
   if (!is.numeric(layout.exp) || layout.exp < 0) {
-    stop("incorrect layout.exp value")
+    cli::cli_abort("incorrect {.arg layout.exp} value")
   } else if (layout.exp > 0) {
     x = scales::expand_range(x, layout.exp / 2)
   }
@@ -1089,14 +1049,13 @@ ggnet2 <- function(
     scale_y_continuous(breaks = NULL) +
     theme(
       panel.background = element_blank(),
-      panel.grid       = element_blank(),
-      axis.title       = element_blank(),
-      legend.key       = element_blank(),
-      legend.position  = legend.position,
-      legend.text      = element_text(size = legend.size),
-      legend.title     = element_text(size = legend.size)
+      panel.grid = element_blank(),
+      axis.title = element_blank(),
+      legend.key = element_blank(),
+      legend.position = legend.position,
+      legend.text = element_text(size = legend.size),
+      legend.title = element_text(size = legend.size)
     )
 
   return(p)
-
 }
