@@ -1,11 +1,3 @@
-if (getRversion() >= "2.15.1") {
-  utils::globalVariables(c(
-    "lon", "lat", "group", "id",
-    "lon1", "lat1", "lon2", "lat2",
-    ".label"
-  ))
-}
-
 #' Network plot map overlay
 #'
 #' Plots a network with \pkg{ggplot2} suitable for overlay on a \pkg{ggmap} plot or \pkg{ggplot2}
@@ -42,140 +34,161 @@ if (getRversion() >= "2.15.1") {
 #' @param ... other arguments supplied to geom_text for the node labels. Arguments pertaining to the title or other items can be achieved through \pkg{ggplot2} methods.
 #' @author Amos Elberg. Original by Moritz Marbach, Francois Briatte
 #' @details This is a function for plotting graphs generated by \code{network} or \code{igraph} in a more flexible and elegant manner than permitted by ggnet.  The function does not need to be the first plot in the ggplot chain, so the graph can be plotted on top of a map or other chart.  Segments can be straight lines, or plotted as great circles.  Note that the great circles feature can produce odd results with arrows and with vertices beyond the plot edges; this is a \pkg{ggplot2} limitation and cannot yet be fixed.  Nodes can have two color schemes, which are then plotted as the center and ring around the node.  The color schemes are selected by adding scale_fill_ or scale_color_ just like any other \pkg{ggplot2} plot. If there are no rings, scale_color sets the color of the nodes.  If there are rings, scale_color sets the color of the rings, and scale_fill sets the color of the centers.  Note that additional arguments in the ... are passed to geom_text for plotting labels.
+#' @importFrom dplyr bind_rows
 #' @importFrom utils installed.packages
 #' @examples
+#' library(dplyr)
 #' # small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
 #' invisible(lapply(c("ggplot2", "maps", "network", "sna"), base::library, character.only = TRUE))
 #'
 #' ## Example showing great circles on a simple map of the USA
-#' ## http://flowingdata.com/2011/05/11/how-to-map-connections-with-great-circles/
-#' \donttest{
-#' airports <- read.csv("http://datasets.flowingdata.com/tuts/maparcs/airports.csv", header = TRUE)
-#' rownames(airports) <- airports$iata
+#' if (require(airports) && require(network) && require(sna)) {
+#'   dms_to_number <- function(dms) {
+#'     parts <- strsplit(dms, "-")[[1]]
+#'     degrees <- as.numeric(parts[1])
+#'     minutes <- as.numeric(parts[2]) / 60
+#'     seconds <- as.numeric(sub(parts[3], pattern = "N|W", replacement = "")) / 3600
+#'     direction <- if (grepl("W", parts[3])) -1 else 1
+#'     return(direction * (degrees + minutes + seconds))
+#'   }
+#'   airports <-
+#'     airports::usairports |>
+#'     filter(
+#'       !is.na(cert_type_date),
+#'       grepl("N", arp_latitude),
+#'       grepl("W", arp_longitude)
+#'     ) |>
+#'     mutate(
+#'       lat = vapply(arp_latitude, dms_to_number, numeric(1)),
+#'       long = vapply(arp_longitude, dms_to_number, numeric(1))
+#'     ) |>
+#'     as.data.frame()
+#'   rownames(airports) <- airports$location_id
 #'
-#' # select some random flights
-#' set.seed(123)
-#' flights <- data.frame(
-#'   origin = sample(airports[200:400, ]$iata, 200, replace = TRUE),
-#'   destination = sample(airports[200:400, ]$iata, 200, replace = TRUE)
-#' )
-#'
-#' # convert to network
-#' flights <- network(flights, directed = TRUE)
-#'
-#' # add geographic coordinates
-#' flights %v% "lat" <- airports[network.vertex.names(flights), "lat"]
-#' flights %v% "lon" <- airports[network.vertex.names(flights), "long"]
-#'
-#' # drop isolated airports
-#' delete.vertices(flights, which(degree(flights) < 2))
-#'
-#' # compute degree centrality
-#' flights %v% "degree" <- degree(flights, gmode = "digraph")
-#'
-#' # add random groups
-#' flights %v% "mygroup" <- sample(letters[1:4], network.size(flights), replace = TRUE)
-#'
-#' # create a map of the USA
-#' usa <- ggplot(map_data("usa"), aes(x = long, y = lat)) +
-#'   geom_polygon(aes(group = group),
-#'     color = "grey65",
-#'     fill = "#f9f9f9", linewidth = 0.2
+#'   # select some random flights
+#'   set.seed(123)
+#'   flights <- data.frame(
+#'     origin = sample(airports[200:400, ]$location_id, 200, replace = TRUE),
+#'     destination = sample(airports[200:400, ]$location_id, 200, replace = TRUE)
 #'   )
 #'
-#' # overlay network data to map
-#' p <- ggnetworkmap(
-#'   usa, flights,
-#'   size = 4, great.circles = TRUE,
-#'   node.group = mygroup, segment.color = "steelblue",
-#'   ring.group = degree, weight = degree
-#' )
-#' p_(p)
+#'   # convert to network
+#'   flights <- network::network(flights, directed = TRUE)
 #'
-#' ## Exploring a community of spambots found on Twitter
-#' ## Data by Amos Elberg: see ?twitter_spambots for details
+#'   # add geographic coordinates
+#'   flights %v% "lat" <- airports[network.vertex.names(flights), "lat"]
+#'   flights %v% "lon" <- airports[network.vertex.names(flights), "long"]
 #'
-#' data(twitter_spambots)
+#'   # drop isolated airports
+#'   network::delete.vertices(flights, which(sna::degree(flights) < 2))
 #'
-#' # create a world map
-#' world <- fortify(map("world", plot = FALSE, fill = TRUE))
-#' world <- ggplot(world, aes(x = long, y = lat)) +
-#'   geom_polygon(aes(group = group),
-#'     color = "grey65",
-#'     fill = "#f9f9f9", linewidth = 0.2
-#'   )
+#'   # compute degree centrality
+#'   flights %v% "degree" <- sna::degree(flights, gmode = "digraph")
 #'
-#' # view global structure
-#' p <- ggnetworkmap(world, twitter_spambots)
-#' p_(p)
+#'   # add random groups
+#'   flights %v% "mygroup" <- sample(letters[1:4], network.size(flights), replace = TRUE)
 #'
-#' # domestic distribution
-#' p <- ggnetworkmap(net = twitter_spambots)
-#' p_(p)
+#'   # create a map of the USA
+#'   usa <- ggplot(map_data("usa"), aes(x = long, y = lat)) +
+#'     geom_polygon(aes(group = group),
+#'       color = "grey65",
+#'       fill = "#f9f9f9", linewidth = 0.2
+#'     )
 #'
-#' # topology
-#' p <- ggnetworkmap(net = twitter_spambots, arrow.size = 0.5)
-#' p_(p)
+#'   # overlay network data to map
+#'   p <- ggnetworkmap(
+#'     usa, flights,
+#'     size = 4, great.circles = TRUE,
+#'     node.group = mygroup, segment.color = "steelblue",
+#'     ring.group = degree, weight = degree
+#'   ) +
+#'     coord_map("albers",  lat0 = 45.5, lat1 = 29.5)
+#'   p_(p)
 #'
-#' # compute indegree and outdegree centrality
-#' twitter_spambots %v% "indegree" <- degree(twitter_spambots, cmode = "indegree")
-#' twitter_spambots %v% "outdegree" <- degree(twitter_spambots, cmode = "outdegree")
+#'   ## Exploring a community of spambots found on Twitter
+#'   ## Data by Amos Elberg: see ?twitter_spambots for details
 #'
-#' p <- ggnetworkmap(
-#'   net = twitter_spambots,
-#'   arrow.size = 0.5,
-#'   node.group = indegree,
-#'   ring.group = outdegree, size = 4
-#' ) +
-#'   scale_fill_continuous("Indegree", high = "red", low = "yellow") +
-#'   labs(color = "Outdegree")
-#' p_(p)
+#'   data(twitter_spambots)
 #'
-#' # show some vertex attributes associated with each account
-#' p <- ggnetworkmap(
-#'   net = twitter_spambots,
-#'   arrow.size = 0.5,
-#'   node.group = followers,
-#'   ring.group = friends,
-#'   size = 4,
-#'   weight = indegree,
-#'   label.nodes = TRUE, vjust = -1.5
-#' ) +
-#'   scale_fill_continuous("Followers", high = "red", low = "yellow") +
-#'   labs(color = "Friends") +
-#'   scale_color_continuous(low = "lightgreen", high = "darkgreen")
-#' p_(p)
+#'   # create a world map
+#'   world <- fortify(map("world", plot = FALSE, fill = TRUE))
+#'   world <- ggplot(world, aes(x = long, y = lat)) +
+#'     geom_polygon(aes(group = group),
+#'       color = "grey65",
+#'       fill = "#f9f9f9", linewidth = 0.2
+#'     )
+#'
+#'   # view global structure
+#'   p <- ggnetworkmap(world, twitter_spambots)
+#'   p_(p)
+#'
+#'   # domestic distribution
+#'   p <- ggnetworkmap(net = twitter_spambots)
+#'   p_(p)
+#'
+#'   # topology
+#'   p <- ggnetworkmap(net = twitter_spambots, arrow.size = 0.5)
+#'   p_(p)
+#'
+#'   # compute indegree and outdegree centrality
+#'   twitter_spambots %v% "indegree" <- sna::degree(twitter_spambots, cmode = "indegree")
+#'   twitter_spambots %v% "outdegree" <- sna::degree(twitter_spambots, cmode = "outdegree")
+#'
+#'   p <- ggnetworkmap(
+#'     net = twitter_spambots,
+#'     arrow.size = 0.5,
+#'     node.group = indegree,
+#'     ring.group = outdegree, size = 4
+#'   ) +
+#'     scale_fill_continuous("Indegree", high = "red", low = "yellow") +
+#'     labs(color = "Outdegree")
+#'   p_(p)
+#'
+#'   # show some vertex attributes associated with each account
+#'   p <- ggnetworkmap(
+#'     net = twitter_spambots,
+#'     arrow.size = 0.5,
+#'     node.group = followers,
+#'     ring.group = friends,
+#'     size = 4,
+#'     weight = indegree,
+#'     label.nodes = TRUE, vjust = -1.5
+#'   ) +
+#'     scale_fill_continuous("Followers", high = "red", low = "yellow") +
+#'     labs(color = "Friends") +
+#'     scale_color_continuous(low = "lightgreen", high = "darkgreen")
+#'   p_(p)
 #' }
 #'
 ggnetworkmap <- function(
-    gg,
-    net,
-    size = 3,
-    alpha = 0.75,
-    weight,
-    node.group,
-    node.color = NULL,
-    node.alpha = NULL,
-    ring.group,
-    segment.alpha = NULL,
-    segment.color = "grey",
-    great.circles = FALSE,
-    segment.size = 0.25,
-    arrow.size = 0,
-    label.nodes = FALSE,
-    label.size = size / 2,
-    ...) {
-  require_namespaces(c("network", "sna"))
+  gg,
+  net,
+  size = 3,
+  alpha = 0.75,
+  weight,
+  node.group,
+  node.color = NULL,
+  node.alpha = NULL,
+  ring.group,
+  segment.alpha = NULL,
+  segment.color = "grey",
+  great.circles = FALSE,
+  segment.size = 0.25,
+  arrow.size = 0,
+  label.nodes = FALSE,
+  label.size = size / 2,
+  ...
+) {
+  rlang::check_installed(c("network", "sna"))
   # sna          # node placement if there is no ggplot object in function call
 
   # -- conversion to network class ---------------------------------------------
 
-  if (inherits(net, "igraph") && "intergraph" %in% rownames(installed.packages())) {
+  if (inherits(net, "igraph")) {
+    rlang::check_installed("intergraph")
     net <- intergraph::asNetwork(net)
-  } else if (inherits(net, "igraph")) {
-    stop("install the 'intergraph' package to use igraph objects with ggnet")
   }
 
   if (!network::is.network(net)) {
@@ -183,7 +196,7 @@ ggnetworkmap <- function(
   }
 
   if (!network::is.network(net)) {
-    stop("could not coerce net to a network object")
+    cli::cli_abort("could not coerce {.arg net} to a {.pkg network} object")
   }
 
   # -- network functions -------------------------------------------------------
@@ -197,22 +210,22 @@ ggnetworkmap <- function(
   is_dir <- ifelse(network::is.directed(net), "digraph", "graph")
 
   if (!is.numeric(arrow.size) || arrow.size < 0) {
-    stop("incorrect arrow.size value")
+    cli::cli_abort("incorrect {.arg arrow.size} value")
   } else if (arrow.size > 0 && is_dir == "graph") {
-    warning("network is undirected; arrow.size ignored")
+    cli::cli_warn("network is undirected; {.arg arrow.size} ignored")
     arrow.size <- 0
   }
 
   if (network::is.hyper(net)) {
-    stop("ggnetworkmap cannot plot hyper graphs")
+    cli::cli_abort("{.fn ggnetworkmap} cannot plot hyper graphs")
   }
 
   if (network::is.multiplex(net)) {
-    stop("ggnetworkmap cannot plot multiplex graphs")
+    cli::cli_abort("{.fn ggnetworkmap} cannot plot multiplex graphs")
   }
 
   if (network::has.loops(net)) {
-    warning("ggnetworkmap does not know how to handle self-loops")
+    cli::cli_warn("{.fn ggnetworkmap} does not know how to handle self-loops")
   }
 
   # -- ... -------------------------------------------------------
@@ -229,13 +242,14 @@ ggnetworkmap <- function(
   if (missing(gg)) {
     # mapproj doesn't need to be loaded, but
     # it needs to exist for ggplot2::coord_map() to work properly
-    if (!("mapproj" %in% installed.packages())) {
-      require_namespaces("mapproj")
-    }
+    rlang::check_installed("mapproj")
     gg <- ggplot() +
       coord_map()
 
-    plotcord <- sna::gplot.layout.fruchtermanreingold(net, list(m, layout.par = NULL))
+    plotcord <- sna::gplot.layout.fruchtermanreingold(
+      net,
+      list(m, layout.par = NULL)
+    )
     plotcord <- data.frame(plotcord)
     colnames(plotcord) <- c("lon", "lat")
   } else {
@@ -295,10 +309,12 @@ ggnetworkmap <- function(
   edges <- data.frame(
     lat1 = plotcord[edges[, 1], "lat"],
     lon1 = plotcord[edges[, 1], "lon"],
-    lat2 =  plotcord[edges[, 2], "lat"],
+    lat2 = plotcord[edges[, 2], "lat"],
     lon2 = plotcord[edges[, 2], "lon"]
   )
-  edges <- subset(na.omit(edges), (!(lat1 == lat2 & lon2 == lon2)))
+  edges <- na.omit(edges)
+  keep_idx <- with(edges, !(lat1 == lat2 & lon2 == lon2))
+  edges <- edges[!is.na(keep_idx) & keep_idx, ]
 
   edge_args <- list(
     linewidth = substitute(segment.size),
@@ -311,7 +327,7 @@ ggnetworkmap <- function(
 
   if (!missing(arrow.size) && arrow.size > 0) {
     edge_args$arrow <- substitute(arrow(
-      type   = "closed",
+      type = "closed",
       length = unit(arrow.size, "cm")
     ))
   }
@@ -320,58 +336,65 @@ ggnetworkmap <- function(
 
   if (great.circles) {
     # geosphere    # great circles
-    require_namespaces("geosphere")
+    rlang::check_installed("geosphere")
 
     pts <- 25 # number of intermediate points for drawing great circles
     i <- 0 # used to keep track of groups when getting intermediate points for great circles
 
-    edges <- ddply(
-      .data = edges,
-      .variables = c("lat1", "lat2", "lon1", "lon2"),
-      .parallel = FALSE,
-      .fun = function(x) {
-        p1Mat <- x[, c("lon1", "lat1")]
-        colnames(p1Mat) <- NULL
-        p2Mat <- x[, c("lon2", "lat2")]
-        colnames(p2Mat) <- NULL
-        inter <- geosphere::gcIntermediate(
-          p1 = p1Mat,
-          p2 = p2Mat,
-          n = pts,
-          addStartEnd = TRUE,
-          breakAtDateLine = TRUE
-        )
+    process_edges <- function(lat1, lat2, lon1, lon2) {
+      p1Mat <- data.frame(lon = lon1, lat = lat1)
+      colnames(p1Mat) <- NULL
+      p2Mat <- data.frame(lon = lon2, lat = lat2)
+      colnames(p2Mat) <- NULL
+      inter <- geosphere::gcIntermediate(
+        p1 = p1Mat,
+        p2 = p2Mat,
+        n = pts,
+        addStartEnd = TRUE,
+        breakAtDateLine = TRUE
+      )
 
-        if (!is.list(inter)) {
+      if (!is.list(inter)) {
+        i <<- i + 1
+        inter <- data.frame(inter)
+        inter$group <- i
+        return(inter)
+      } else {
+        if (is.matrix(inter[[1]])) {
           i <<- i + 1
-          inter <- data.frame(inter)
-          inter$group <- i
-          return(inter)
+          ret <- data.frame(inter[[1]])
+          ret$group <- i
+          i <<- i + 1
+          ret2 <- data.frame(inter[[2]])
+          ret2$group <- i
+          return(rbind(ret, ret2))
         } else {
-          if (is.matrix(inter[[1]])) {
+          ret <- data.frame(
+            lon = numeric(0),
+            lat = numeric(0),
+            group = numeric(0)
+          )
+          for (j in 1:length(inter)) {
             i <<- i + 1
-            ret <- data.frame(inter[[1]])
-            ret$group <- i
+            ret1 <- data.frame(inter[[j]][[1]])
+            ret1$group <- i
             i <<- i + 1
-            ret2 <- data.frame(inter[[2]])
+            ret2 <- data.frame(inter[[j]][[2]])
             ret2$group <- i
-            return(rbind(ret, ret2))
-          } else {
-            ret <- data.frame(lon = numeric(0), lat = numeric(0), group = numeric(0))
-            for (j in 1:length(inter)) {
-              i <<- i + 1
-              ret1 <- data.frame(inter[[j]][[1]])
-              ret1$group <- i
-              i <<- i + 1
-              ret2 <- data.frame(inter[[j]][[2]])
-              ret2$group <- i
-              ret <- rbind(ret, ret1, ret2)
-            }
-            return(ret)
+            ret <- rbind(ret, ret1, ret2)
           }
+          return(ret)
         }
       }
-    )
+    }
+
+    edges <-
+      edges |>
+      reframe(
+        .by = c("lat1", "lat2", "lon1", "lon2"),
+        process_edges(.data$lat1, .data$lat2, .data$lon1, .data$lon2)
+      ) |>
+      dplyr::select("lat", "lon", "group")
 
     edge_aes$x <- substitute(lon)
     edge_aes$y <- substitute(lat)
@@ -395,7 +418,6 @@ ggnetworkmap <- function(
   #
   #
 
-
   # custom weights: vertex attribute
   # null weighting
   sizer <- NULL
@@ -407,7 +429,10 @@ ggnetworkmap <- function(
 
     # proportional scaling
     if (is.factor(plotcord$.weight)) {
-      sizer <- scale_size_discrete(name = substitute(weight), range = c(size / nlevels(plotcord$weight), size))
+      sizer <- scale_size_discrete(
+        name = substitute(weight),
+        range = c(size / nlevels(plotcord$weight), size)
+      )
     } else {
       sizer <- scale_size_area(name = substitute(weight), max_size = size)
     }
@@ -430,11 +455,13 @@ ggnetworkmap <- function(
   # -- node labels -------------------------------------------------------------
 
   if (isTRUE(labels)) {
-    gg <- gg + geom_text(
-      data = plotcord,
-      aes(x = lon, y = lat, label = .label),
-      size = label.size, ...
-    )
+    gg <- gg +
+      geom_text(
+        data = plotcord,
+        aes(x = .data$lon, y = .data$lat, label = .data$.label),
+        size = label.size,
+        ...
+      )
   }
 
   gg <- gg +
