@@ -1,7 +1,5 @@
 #' @importFrom dplyr all_of
-if (getRversion() >= "2.15.1") {
-  utils::globalVariables(c("variable", "value", "ggally_splineFactor", ".ggally_ggcorr_row_names"))
-}
+NULL
 
 #' Parallel coordinate plot
 #'
@@ -77,7 +75,7 @@ if (getRversion() >= "2.15.1") {
 #' @param title character string denoting the title of the plot
 #' @author Jason Crowley, Barret Schloerke, Dianne Cook, Heike Hofmann, Hadley Wickham
 #' @return ggplot object that if called, will print
-#' @importFrom plyr ddply summarize
+#' @importFrom dplyr across arrange bind_cols everything n reframe summarise mutate
 #' @importFrom stats complete.cases sd median mad lm spline
 #' @importFrom tidyr pivot_longer
 #' @export
@@ -161,21 +159,22 @@ if (getRversion() >= "2.15.1") {
 #' p <- ggparcoord(diamonds.samp, columns, groupColumn = 2, splineFactor = 3)
 #' p_(p)
 ggparcoord <- function(
-    data,
-    columns = 1:ncol(data),
-    groupColumn = NULL,
-    scale = "std",
-    scaleSummary = "mean",
-    centerObsID = 1,
-    missing = "exclude",
-    order = columns,
-    showPoints = FALSE,
-    splineFactor = FALSE,
-    alphaLines = 1,
-    boxplot = FALSE,
-    shadeBox = NULL,
-    mapping = NULL,
-    title = "") {
+  data,
+  columns = 1:ncol(data),
+  groupColumn = NULL,
+  scale = "std",
+  scaleSummary = "mean",
+  centerObsID = 1,
+  missing = "exclude",
+  order = columns,
+  showPoints = FALSE,
+  splineFactor = FALSE,
+  alphaLines = 1,
+  boxplot = FALSE,
+  shadeBox = NULL,
+  mapping = NULL,
+  title = ""
+) {
   if (!identical(class(data), "data.frame")) {
     data <- as.data.frame(data)
   }
@@ -184,87 +183,122 @@ ggparcoord <- function(
   ### Error Checking ###
   if (is.null(groupColumn)) {
     if (any(tolower(order) %in% c("anyclass", "allclass"))) {
-      stop("can't use the 'order' methods anyClass or allClass without specifying groupColumn")
+      cli::cli_abort(
+        "can't use the {.arg order} methods {.val anyClass} or {.val allClass} without specifying groupColumn"
+      )
     }
   } else if (
-    !((length(groupColumn) == 1) && (is.numeric(groupColumn) || is.character(groupColumn)))
+    !((length(groupColumn) == 1) &&
+      (is.numeric(groupColumn) || is.character(groupColumn)))
   ) {
-    stop("invalid value for 'groupColumn'; must be a single numeric or character index")
+    cli::cli_abort(
+      "invalid value for {.arg groupColumn}; must be a single numeric or character index"
+    )
   }
 
-  if (!(tolower(scale) %in% c(
-    "std", "robust", "uniminmax", "globalminmax", "center", "centerobs"
-  ))) {
-    stop(str_c(
-      "invalid value for 'scale'; must be one of ",
-      "'std', 'robust', 'uniminmax', 'globalminmax', 'center', or 'centerObs'"
+  if (
+    !(tolower(scale) %in%
+      c(
+        "std",
+        "robust",
+        "uniminmax",
+        "globalminmax",
+        "center",
+        "centerobs"
+      ))
+  ) {
+    cli::cli_abort(c(
+      "invalid value for {.arg scale}; must be one of {.val std}, {.val robust}, {.val uniminmax}, {.val globalminmax}, {.val center}, or {.val centerObs}."
     ))
   }
 
   if (!(centerObsID %in% 1:dim(data)[1])) {
-    stop("invalid value for 'centerObsID'; must be a single numeric row index")
-  }
-
-  if (!(tolower(missing) %in% c("exclude", "mean", "median", "min10", "random"))) {
-    stop(
-      "invalid value for 'missing'; must be one of 'exclude', 'mean', 'median', 'min10', 'random'"
+    cli::cli_abort(
+      "invalid value for {.arg centerObsID}; must be a single numeric row index"
     )
   }
 
-  if (!(
-    is.numeric(order) || (
-      is.character(order) && (
-        order %in% c(
-          "skewness", "allClass", "anyClass", "Outlying", "Skewed", "Clumpy",
-          "Sparse", "Striated", "Convex", "Skinny", "Stringy", "Monotonic"
-        )
+  if (
+    !(tolower(missing) %in% c("exclude", "mean", "median", "min10", "random"))
+  ) {
+    cli::cli_abort(
+      "invalid value for {.arg missing}; must be one of {.val exclude}, {.val mean}, {.val median}, {.val min10}, {.val random}."
+    )
+  }
+
+  possibleOrderValues <- c(
+    "skewness",
+    "allClass",
+    "anyClass",
+    "Outlying",
+    "Skewed",
+    "Clumpy",
+    "Sparse",
+    "Striated",
+    "Convex",
+    "Skinny",
+    "Stringy",
+    "Monotonic"
+  )
+  if (
+    !(is.numeric(order) ||
+      (is.character(order) && (order %in% possibleOrderValues)))
+  ) {
+    cli::cli_abort(
+      c(
+        "invalid value for {.arg order}",
+        "i" = "must either be a vector of column indices or one of {.or {.code {possibleOrderValues}}}"
       )
     )
-  )
-  ) {
-    stop(str_c(
-      "invalid value for 'order'; must either be a vector of column indices or one of ",
-      "'skewness', 'allClass', 'anyClass', 'Outlying', 'Skewed', 'Clumpy', 'Sparse', 'Striated', ",
-      "'Convex', 'Skinny', 'Stringy', 'Monotonic'"
-    ))
   }
 
   if (!(is.logical(showPoints))) {
-    stop("invalid value for 'showPoints'; must be a logical operator")
+    cli::cli_abort(
+      "invalid value for {.arg showPoints}; must be a logical operator"
+    )
   }
 
   alphaLinesIsCharacter <- is.character(alphaLines)
   if (alphaLinesIsCharacter) {
     if (!(alphaLines %in% names(data))) {
-      stop("'alphaLines' column is missing in data")
+      cli::cli_abort("{.arg alphaLines} column is missing in data")
     }
 
     alphaVar <- data[[alphaLines]]
     alphaRange <- range(alphaVar)
     if (any(is.na(alphaRange))) {
-      stop("missing data in 'alphaLines' column")
+      cli::cli_abort("missing data in {.arg alphaLines} column")
     }
 
     if (alphaRange[1] < 0 || alphaRange[2] > 1) {
-      stop("invalid value for 'alphaLines' column; max range must be from 0 to 1")
+      cli::cli_abort(
+        "invalid value for {.arg alphaLines} column; max range must be from 0 to 1"
+      )
     }
-  } else if ((alphaLines < 0) || (alphaLines > 1)) { # nolint
-    stop("invalid value for 'alphaLines'; must be a scalar value between 0 and 1")
+  } else if ((alphaLines < 0) || (alphaLines > 1)) {
+    cli::cli_abort(
+      "invalid value for {.arg alphaLines}; must be a scalar value between 0 and 1"
+    )
   }
 
   if (!(is.logical(boxplot))) {
-    stop("invalid value for 'boxplot'; must be a logical operator")
+    cli::cli_abort(
+      "invalid value for {.arg boxplot}; must be a logical operator"
+    )
   }
 
   if (!is.null(shadeBox) && length(shadeBox) != 1) {
-    stop("invalid value for 'shadeBox'; must be a single color")
+    cli::cli_abort("invalid value for {.arg shadeBox}; must be a single color")
   } else {
-    valid_color <- tryCatch(is.matrix(grDevices::col2rgb(shadeBox)),
+    valid_color <- tryCatch(
+      is.matrix(grDevices::col2rgb(shadeBox)),
       error = function(e) FALSE
     )
 
     if (!valid_color) {
-      stop("invalid value for 'shadeBox'; must be a valid R color")
+      cli::cli_abort(
+        "invalid value for {.arg shadeBox}; must be a valid R color"
+      )
     }
   }
 
@@ -275,10 +309,11 @@ ggparcoord <- function(
       splineFactor <- 0
     }
   } else if (!is.numeric(splineFactor)) {
-    stop("invalid value for 'splineFactor'; must be a logical or numeric value")
+    cli::cli_abort(
+      "invalid value for {.arg splineFactor}; must be a logical or numeric value"
+    )
   }
 
-
   ### Setup ###
   if (is.numeric(groupColumn)) {
     groupColumn <- names(data)[groupColumn]
@@ -327,9 +362,10 @@ ggparcoord <- function(
   inner_rescaler_default <- function(x, type = "sd", ...) {
     # copied directly from reshape because of import difficulties :-(
     # rescaler.default
-    switch(type,
+    switch(
+      type,
       rank = rank(x, ...),
-      var = , # nolint
+      var = ,
       sd = (x - mean(x, na.rm = TRUE)) / sd(x, na.rm = TRUE),
       robust = (x - median(x, na.rm = TRUE)) / mad(x, na.rm = TRUE),
       I = x,
@@ -354,7 +390,12 @@ ggparcoord <- function(
         x[ind] <- lapply(x[ind], inner_rescaler_default, type = type, ...)
         x[singleVal] <- 1
       } else {
-        x[continuous] <- lapply(x[continuous], inner_rescaler_default, type = type, ...)
+        x[continuous] <- lapply(
+          x[continuous],
+          inner_rescaler_default,
+          type = type,
+          ...
+        )
       }
     }
     x
@@ -368,17 +409,23 @@ ggparcoord <- function(
       "uniminmax" = "range",
       "center" = "range"
     )[tolower(scale)]
-    data[columnsPlusTwo] <- inner_rescaler(data[columnsPlusTwo], type = rescalerType)
+    data[columnsPlusTwo] <- inner_rescaler(
+      data[columnsPlusTwo],
+      type = rescalerType
+    )
 
     if (tolower(scale) == "center") {
       data[columns] <- apply(data[columns], 2, function(x) {
-        x <- x - eval(
-          parse(text = paste(
-            scaleSummary,
-            "(x, na.rm=TRUE)",
-            sep = ""
-          ))
-        )
+        x <- x -
+          eval(
+            parse(
+              text = paste(
+                scaleSummary,
+                "(x, na.rm=TRUE)",
+                sep = ""
+              )
+            )
+          )
       })
     }
   }
@@ -396,6 +443,7 @@ ggparcoord <- function(
     }
 
     data <- data[dataCompleteCases, ]
+    saveData2 <- saveData2[dataCompleteCases, ]
   } else if (tolower(missing) %in% c("mean", "median", "min10", "random")) {
     missingFns <- list(
       mean = function(x) {
@@ -464,13 +512,26 @@ ggparcoord <- function(
   ### Ordering ###
   if (length(order) > 1 && is.numeric(order)) {
     data.m$variable <- factor(data.m$variable, levels = names(saveData)[order])
-  } else if (order %in% c(
-    "Outlying", "Skewed", "Clumpy", "Sparse", "Striated", "Convex", "Skinny",
-    "Stringy", "Monotonic"
-  )) {
-    require_namespaces("scagnostics")
+  } else if (
+    order %in%
+      c(
+        "Outlying",
+        "Skewed",
+        "Clumpy",
+        "Sparse",
+        "Striated",
+        "Convex",
+        "Skinny",
+        "Stringy",
+        "Monotonic"
+      )
+  ) {
+    rlang::check_installed("scagnostics")
     scag <- scagnostics::scagnostics(saveData2)
-    data.m$variable <- factor(data.m$variable, levels = scag_order(scag, names(saveData2), order))
+    data.m$variable <- factor(
+      data.m$variable,
+      levels = scag_order(scag, names(saveData2), order)
+    )
   } else if (tolower(order) == "skewness") {
     abs.skew <- abs(apply(saveData2, 2, skewness))
     data.m$variable <- factor(
@@ -512,24 +573,30 @@ ggparcoord <- function(
 
   if (!is.null(shadeBox)) {
     # Fix so that if missing = "min10", the box only goes down to the true min
-    d.sum <- ddply(data.m, c("variable"), summarize,
-      min = min(value),
-      max = max(value)
-    )
-    p <- p + geom_linerange(
-      data = d.sum, linewidth = I(10), col = shadeBox,
-      inherit.aes = FALSE,
-      mapping = aes(
-        x = !!as.name("variable"),
-        ymin = !!as.name("min"),
-        ymax = !!as.name("max"),
-        group = !!as.name("variable")
+    d.sum <- data.m |>
+      summarise(
+        min = min(.data$value),
+        max = max(.data$value),
+        .by = "variable"
+      ) |>
+      arrange(.data$variable)
+    p <- p +
+      geom_linerange(
+        data = d.sum,
+        linewidth = I(10),
+        col = shadeBox,
+        inherit.aes = FALSE,
+        mapping = aes(
+          x = !!as.name("variable"),
+          ymin = !!as.name("min"),
+          ymax = !!as.name("max"),
+          group = !!as.name("variable")
+        )
       )
-    )
   }
 
   if (boxplot) {
-    p <- p + geom_boxplot(mapping = aes(group = !!as.name("variable")), alpha = 0.8)
+    p <- p + geom_boxplot(mapping = aes(group = .data$variable), alpha = 0.8)
   }
 
   if (!is.null(mapping2$linewidth)) {
@@ -541,14 +608,51 @@ ggparcoord <- function(
   if (splineFactor > 0) {
     data.m$ggally_splineFactor <- splineFactor
     if (inherits(splineFactor, "AsIs")) {
-      data.m <- ddply(
-        data.m, ".ID", transform,
-        spline = spline(variable, value, n = ggally_splineFactor[1])
+      data.m <- bind_cols(
+        reframe(
+          data.m,
+          .by = ".ID",
+          across(
+            everything(),
+            function(x) rep(x, .data$ggally_splineFactor[1] / length(x))
+          )
+        ),
+        mutate(
+          reframe(
+            data.m,
+            .by = ".ID",
+            data.frame(spline(
+              .data$variable,
+              .data$value,
+              n = .data$ggally_splineFactor[1]
+            ))
+          ),
+          spline.x = .data$x,
+          spline.y = .data$y,
+          .keep = "none"
+        )
       )
     } else {
-      data.m <- ddply(
-        data.m, ".ID", transform,
-        spline = spline(variable, value, n = length(variable) * ggally_splineFactor[1])
+      data.m <- bind_cols(
+        reframe(
+          data.m,
+          .by = ".ID",
+          across(everything(), function(x) rep(x, .data$ggally_splineFactor[1]))
+        ),
+        mutate(
+          reframe(
+            data.m,
+            .by = ".ID",
+            data.frame(spline(
+              .data$variable,
+              .data$value,
+              n = n() * .data$ggally_splineFactor[1]
+            ))
+          ),
+          spline.x = .data$x,
+          spline.y = .data$y,
+          .keep = "none"
+        )
       )
     }
 
@@ -558,7 +662,11 @@ ggparcoord <- function(
     if (alphaLinesIsCharacter) {
       p <- p +
         geom_line(
-          aes(x = !!as.name(linexvar), y = !!as.name(lineyvar), alpha = !!as.name(alphaLines)),
+          aes(
+            x = !!as.name(linexvar),
+            y = !!as.name(lineyvar),
+            alpha = !!as.name(alphaLines)
+          ),
           linewidth = lineSize,
           data = data.m
         ) +
@@ -574,20 +682,25 @@ ggparcoord <- function(
     }
 
     if (showPoints) {
-      p <- p + geom_point(aes(x = as.numeric(variable), y = value))
+      p <- p + geom_point(aes(x = as.numeric(.data$variable), y = .data$value))
     }
 
     xAxisLabels <- levels(data.m$variable)
     # while continuous data, this makes it present like it's discrete
-    p <- p + scale_x_continuous(
-      breaks = seq_along(xAxisLabels),
-      labels = xAxisLabels,
-      minor_breaks = FALSE
-    )
+    p <- p +
+      scale_x_continuous(
+        breaks = seq_along(xAxisLabels),
+        labels = xAxisLabels,
+        minor_breaks = FALSE
+      )
   } else {
     if (alphaLinesIsCharacter) {
       p <- p +
-        geom_line(aes(alpha = !!as.name(alphaLines)), linewidth = lineSize, data = data.m) +
+        geom_line(
+          aes(alpha = !!as.name(alphaLines)),
+          linewidth = lineSize,
+          data = data.m
+        ) +
         scale_alpha(range = alphaRange)
     } else {
       # p <- p + geom_line(alpha = alphaLines, linewidth = lineSize)
@@ -603,6 +716,12 @@ ggparcoord <- function(
     p <- p + labs(title = title)
   }
 
+  p <- p +
+    labs(
+      x = "variable",
+      y = "value"
+    )
+
   p
 }
 
@@ -645,7 +764,11 @@ scag_order <- function(scag, vars, measure) {
     nameLoc <- nameLocs[[i]]
     scagName <- scagNames[[i]]
     # retrieve the column name from "FIRSTNAME * SECONDNAME"
-    substr(rep(scagName, 2), nameLoc[-1], nameLoc[-1] + attr(nameLoc, "match.length")[-1] - 1)
+    substr(
+      rep(scagName, 2),
+      nameLoc[-1],
+      nameLoc[-1] + attr(nameLoc, "match.length")[-1] - 1
+    )
   })
 
   ret <- c()
@@ -681,10 +804,9 @@ scag_order <- function(scag, vars, measure) {
   }
 
   if (length(ret) != length(vars)) {
-    stop(str_c(
-      "Could not compute a correct ordering: ",
-      length(vars) - length(ret), " values are missing. ",
-      "Missing: ", paste0(vars[!(vars %in% ret)], collapse = ", ")
+    cli::cli_abort(c(
+      "Could not compute a correct ordering: {length(vars) - length(ret)} values are missing.",
+      "Missing: {toString(vars[!(vars %in% ret)])}"
     ))
   }
 
@@ -714,13 +836,17 @@ singleClassOrder <- function(classVar, axisVars, specClass = NULL) {
   } else {
     var.names <- colnames(axisVars)
     class.names <- levels(classVar)
-    f.stats <- matrix(NA,
-      nrow = length(class.names), ncol = length(var.names), dimnames =
-        list(class.names, var.names)
+    f.stats <- matrix(
+      NA,
+      nrow = length(class.names),
+      ncol = length(var.names),
+      dimnames = list(class.names, var.names)
     )
     for (i in 1:length(class.names)) {
       f.stats[i, ] <- apply(axisVars, 2, function(x) {
-        return(summary(lm(x ~ as.factor(classVar == class.names[i])))$fstatistic[1])
+        return(summary(lm(
+          x ~ as.factor(classVar == class.names[i])
+        ))$fstatistic[1])
       })
     }
     var.maxF <- apply(f.stats, 2, max)
@@ -740,6 +866,8 @@ skewness <- function(x) {
   x <- x[!is.na(x)]
   xbar <- mean(x)
   n <- length(x)
-  skewness <- (1 / n) * sum((x - xbar)^3) / ((1 / n) * sum((x - xbar)^2))^(3 / 2)
+  skewness <- (1 / n) *
+    sum((x - xbar)^3) /
+    ((1 / n) * sum((x - xbar)^2))^(3 / 2)
   return(skewness)
 }
