@@ -1,16 +1,23 @@
-
 suppressMessages(require(broom))
 
 test_that("example", {
-  reg <- lm(Sepal.Length ~ Sepal.Width + Petal.Length + Petal.Width, data = iris)
+  reg <- lm(
+    Sepal.Length ~ Sepal.Width + Petal.Length + Petal.Width,
+    data = iris
+  )
   p <- ggcoef(reg)
-  vdiffr::expect_doppelganger("lm", p)
+  ggally_expect_doppelganger("lm", p)
 
   skip_if_not_installed("MASS")
   d <- as.data.frame(Titanic)
-  reg2 <- glm(Survived ~ Sex + Age + Class, family = binomial, data = d, weights = d$Freq)
+  reg2 <- glm(
+    Survived ~ Sex + Age + Class,
+    family = binomial,
+    data = d,
+    weights = d$Freq
+  )
   p <- ggcoef(reg2, exponentiate = TRUE)
-  vdiffr::expect_doppelganger("lm-expo", p)
+  ggally_expect_doppelganger("lm-expo", p)
   p <- ggcoef(
     reg2,
     exponentiate = TRUE,
@@ -18,5 +25,5 @@ test_that("example", {
     errorbar_height = .2,
     color = "blue"
   )
-  vdiffr::expect_doppelganger("lm-expo-blue", p)
+  ggally_expect_doppelganger("lm-expo-blue", p)
 })
